0 BOS/EOS,*,*,*,*,*,*
1 その他,間投,*,*,*,*,*
2 フィラー,*,*,*,*,*,*
3 フィラー,*,*,*,*,*,あ
4 フィラー,*,*,*,*,*,あの
5 フィラー,*,*,*,*,*,あのー
6 フィラー,*,*,*,*,*,あー
7 フィラー,*,*,*,*,*,え
8 フィラー,*,*,*,*,*,えー
9 フィラー,*,*,*,*,*,えーと
10 フィラー,*,*,*,*,*,と
11 フィラー,*,*,*,*,*,ま
12 副詞,一般,*,*,*,*,*
13 副詞,一般,*,*,*,*,1
14 副詞,一般,*,*,*,*,2
15 副詞,一般,*,*,*,*,3
16 副詞,一般,*,*,*,*,4
17 副詞,一般,*,*,*,*,5
18 副詞,一般,*,*,*,*,6
19 副詞,一般,*,*,*,*,7
20 副詞,一般,*,*,*,*,8
21 副詞,一般,*,*,*,*,もう
22 副詞,一般,*,*,*,*,よく
23 副詞,一般,*,*,*,*,より
24 副詞,助詞類接続,*,*,*,*,*
25 副詞,助詞類接続,*,*,*,*,1
26 副詞,助詞類接続,*,*,*,*,2
27 副詞,助詞類接続,*,*,*,*,3
28 副詞,助詞類接続,*,*,*,*,4
29 副詞,助詞類接続,*,*,*,*,5
30 副詞,助詞類接続,*,*,*,*,6
31 副詞,助詞類接続,*,*,*,*,7
32 副詞,助詞類接続,*,*,*,*,8
33 副詞,助詞類接続,*,*,*,*,こう
34 副詞,助詞類接続,*,*,*,*,さ
35 副詞,助詞類接続,*,*,*,*,さらに
36 副詞,助詞類接続,*,*,*,*,すぐ
37 副詞,助詞類接続,*,*,*,*,そう
38 副詞,助詞類接続,*,*,*,*,どう
39 副詞,助詞類接続,*,*,*,*,どぉ
40 副詞,助詞類接続,*,*,*,*,なぜ
41 副詞,助詞類接続,*,*,*,*,まだ
42 助動詞,*,*,*,下二・タ行,仮定形,つ
43 助動詞,*,*,*,下二・タ行,体言接続,つ
44 助動詞,*,*,*,下二・タ行,命令ｙｏ,つ
45 助動詞,*,*,*,下二・タ行,基本形,つ
46 助動詞,*,*,*,下二・タ行,未然形,つ
47 助動詞,*,*,*,下二・タ行,連用形,つ
48 助動詞,*,*,*,不変化型,基本形,う
49 助動詞,*,*,*,不変化型,基本形,じ
50 助動詞,*,*,*,不変化型,基本形,じゃん
51 助動詞,*,*,*,不変化型,基本形,じゃン
52 助動詞,*,*,*,不変化型,基本形,ぬ
53 助動詞,*,*,*,不変化型,基本形,ひん
54 助動詞,*,*,*,不変化型,基本形,へん
55 助動詞,*,*,*,不変化型,基本形,まい
56 助動詞,*,*,*,不変化型,基本形,やん
57 助動詞,*,*,*,不変化型,基本形,ん
58 助動詞,*,*,*,五段・ラ行アル,仮定形,ある
59 助動詞,*,*,*,五段・ラ行アル,仮定縮約１,ある
60 助動詞,*,*,*,五段・ラ行アル,体言接続特殊,ある
61 助動詞,*,*,*,五段・ラ行アル,命令ｅ,ある
62 助動詞,*,*,*,五段・ラ行アル,基本形,ある
63 助動詞,*,*,*,五段・ラ行アル,未然ウ接続,ある
64 助動詞,*,*,*,五段・ラ行アル,未然形,ある
65 助動詞,*,*,*,五段・ラ行アル,連用タ接続,ある
66 助動詞,*,*,*,五段・ラ行アル,連用形,ある
67 助動詞,*,*,*,五段・ラ行特殊,仮定形,ござる
68 助動詞,*,*,*,五段・ラ行特殊,仮定形,御座る
69 助動詞,*,*,*,五段・ラ行特殊,仮定縮約１,ござる
70 助動詞,*,*,*,五段・ラ行特殊,仮定縮約１,御座る
71 助動詞,*,*,*,五段・ラ行特殊,命令ｅ,ござる
72 助動詞,*,*,*,五段・ラ行特殊,命令ｅ,御座る
73 助動詞,*,*,*,五段・ラ行特殊,命令ｉ,ござる
74 助動詞,*,*,*,五段・ラ行特殊,命令ｉ,御座る
75 助動詞,*,*,*,五段・ラ行特殊,基本形,ござる
76 助動詞,*,*,*,五段・ラ行特殊,基本形,ゴザル
77 助動詞,*,*,*,五段・ラ行特殊,基本形,御座る
78 助動詞,*,*,*,五段・ラ行特殊,未然ウ接続,ござる
79 助動詞,*,*,*,五段・ラ行特殊,未然ウ接続,御座る
80 助動詞,*,*,*,五段・ラ行特殊,未然形,ござる
81 助動詞,*,*,*,五段・ラ行特殊,未然形,御座る
82 助動詞,*,*,*,五段・ラ行特殊,未然特殊,ござる
83 助動詞,*,*,*,五段・ラ行特殊,未然特殊,御座る
84 助動詞,*,*,*,五段・ラ行特殊,連用タ接続,ござる
85 助動詞,*,*,*,五段・ラ行特殊,連用タ接続,御座る
86 助動詞,*,*,*,五段・ラ行特殊,連用形,ござる
87 助動詞,*,*,*,五段・ラ行特殊,連用形,ゴザル
88 助動詞,*,*,*,五段・ラ行特殊,連用形,御座る
89 助動詞,*,*,*,形容詞・イ段,ガル接続,らしい
90 助動詞,*,*,*,形容詞・イ段,ガル接続,無い
91 助動詞,*,*,*,形容詞・イ段,仮定形,らしい
92 助動詞,*,*,*,形容詞・イ段,仮定形,無い
93 助動詞,*,*,*,形容詞・イ段,仮定縮約１,らしい
94 助動詞,*,*,*,形容詞・イ段,仮定縮約１,無い
95 助動詞,*,*,*,形容詞・イ段,仮定縮約２,らしい
96 助動詞,*,*,*,形容詞・イ段,仮定縮約２,無い
97 助動詞,*,*,*,形容詞・イ段,体言接続,らしい
98 助動詞,*,*,*,形容詞・イ段,体言接続,無い
99 助動詞,*,*,*,形容詞・イ段,命令ｅ,らしい
100 助動詞,*,*,*,形容詞・イ段,命令ｅ,無い
101 助動詞,*,*,*,形容詞・イ段,基本形,らしい
102 助動詞,*,*,*,形容詞・イ段,基本形,無い
103 助動詞,*,*,*,形容詞・イ段,文語基本形,らしい
104 助動詞,*,*,*,形容詞・イ段,文語基本形,無い
105 助動詞,*,*,*,形容詞・イ段,未然ウ接続,らしい
106 助動詞,*,*,*,形容詞・イ段,未然ウ接続,無い
107 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,らしい
108 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,無い
109 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,らしい
110 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,無い
111 助動詞,*,*,*,形容詞・イ段,連用タ接続,らしい
112 助動詞,*,*,*,形容詞・イ段,連用タ接続,無い
113 助動詞,*,*,*,形容詞・イ段,連用テ接続,らしい
114 助動詞,*,*,*,形容詞・イ段,連用テ接続,無い
115 助動詞,*,*,*,文語・キ,体言接続,き
116 助動詞,*,*,*,文語・キ,命令ｅ,き
117 助動詞,*,*,*,文語・キ,基本形,き
118 助動詞,*,*,*,文語・ケリ,体言接続,けり
119 助動詞,*,*,*,文語・ケリ,基本形,けり
120 助動詞,*,*,*,文語・ゴトシ,体言接続,ごとし
121 助動詞,*,*,*,文語・ゴトシ,体言接続,如し
122 助動詞,*,*,*,文語・ゴトシ,基本形,ごとし
123 助動詞,*,*,*,文語・ゴトシ,基本形,如し
124 助動詞,*,*,*,文語・ゴトシ,連用形,ごとし
125 助動詞,*,*,*,文語・ゴトシ,連用形,如し
126 助動詞,*,*,*,文語・ナリ,仮定形,たり
127 助動詞,*,*,*,文語・ナリ,仮定形,なり
128 助動詞,*,*,*,文語・ナリ,体言接続,たり
129 助動詞,*,*,*,文語・ナリ,体言接続,なり
130 助動詞,*,*,*,文語・ナリ,体言接続,タリ
131 助動詞,*,*,*,文語・ナリ,命令ｅ,たり
132 助動詞,*,*,*,文語・ナリ,命令ｅ,なり
133 助動詞,*,*,*,文語・ナリ,基本形,たり
134 助動詞,*,*,*,文語・ナリ,基本形,なり
135 助動詞,*,*,*,文語・ナリ,未然形,たり
136 助動詞,*,*,*,文語・ナリ,未然形,なり
137 助動詞,*,*,*,文語・ベシ,仮定形,べし
138 助動詞,*,*,*,文語・ベシ,体言接続,べし
139 助動詞,*,*,*,文語・ベシ,基本形,べし
140 助動詞,*,*,*,文語・ベシ,基本形,ベシ
141 助動詞,*,*,*,文語・ベシ,未然形,べし
142 助動詞,*,*,*,文語・ベシ,連用形,べし
143 助動詞,*,*,*,文語・マジ,仮定形,まじ
144 助動詞,*,*,*,文語・マジ,体言接続,まじ
145 助動詞,*,*,*,文語・マジ,基本形,まじ
146 助動詞,*,*,*,文語・マジ,連用形,まじ
147 助動詞,*,*,*,文語・リ,体言接続,り
148 助動詞,*,*,*,文語・リ,基本形,り
149 助動詞,*,*,*,文語・ル,仮定形,る
150 助動詞,*,*,*,文語・ル,体言接続,る
151 助動詞,*,*,*,文語・ル,命令ｅ,る
152 助動詞,*,*,*,文語・ル,命令ｙｏ,る
153 助動詞,*,*,*,文語・ル,基本形,る
154 助動詞,*,*,*,文語・ル,未然形,る
155 助動詞,*,*,*,文語・ル,連用形,る
156 助動詞,*,*,*,特殊・ジャ,基本形,じゃ
157 助動詞,*,*,*,特殊・ジャ,未然形,じゃ
158 助動詞,*,*,*,特殊・ジャ,連用形,じゃ
159 助動詞,*,*,*,特殊・タ,仮定形,た
160 助動詞,*,*,*,特殊・タ,仮定形,だ
161 助動詞,*,*,*,特殊・タ,基本形,た
162 助動詞,*,*,*,特殊・タ,基本形,だ
163 助動詞,*,*,*,特殊・タ,未然形,た
164 助動詞,*,*,*,特殊・タ,未然形,だ
165 助動詞,*,*,*,特殊・タイ,ガル接続,たい
166 助動詞,*,*,*,特殊・タイ,仮定形,たい
167 助動詞,*,*,*,特殊・タイ,仮定縮約１,たい
168 助動詞,*,*,*,特殊・タイ,仮定縮約２,たい
169 助動詞,*,*,*,特殊・タイ,体言接続,たい
170 助動詞,*,*,*,特殊・タイ,基本形,たぁい
171 助動詞,*,*,*,特殊・タイ,基本形,たい
172 助動詞,*,*,*,特殊・タイ,基本形,たーい
173 助動詞,*,*,*,特殊・タイ,基本形,た～い
174 助動詞,*,*,*,特殊・タイ,文語基本形,たい
175 助動詞,*,*,*,特殊・タイ,未然ウ接続,たい
176 助動詞,*,*,*,特殊・タイ,未然ヌ接続,たい
177 助動詞,*,*,*,特殊・タイ,連用ゴザイ接続,たい
178 助動詞,*,*,*,特殊・タイ,連用タ接続,たい
179 助動詞,*,*,*,特殊・タイ,連用テ接続,たい
180 助動詞,*,*,*,特殊・タイ,音便基本形,たい
181 助動詞,*,*,*,特殊・ダ,仮定形,だ
182 助動詞,*,*,*,特殊・ダ,体言接続,だ
183 助動詞,*,*,*,特殊・ダ,命令ｅ,だ
184 助動詞,*,*,*,特殊・ダ,基本形,だ
185 助動詞,*,*,*,特殊・ダ,未然形,だ
186 助動詞,*,*,*,特殊・ダ,連用タ接続,だ
187 助動詞,*,*,*,特殊・ダ,連用形,だ
188 助動詞,*,*,*,特殊・デス,基本形,っす
189 助動詞,*,*,*,特殊・デス,基本形,でぇす
190 助動詞,*,*,*,特殊・デス,基本形,です
191 助動詞,*,*,*,特殊・デス,基本形,でっす
192 助動詞,*,*,*,特殊・デス,基本形,でーす
193 助動詞,*,*,*,特殊・デス,基本形,で～す
194 助動詞,*,*,*,特殊・デス,基本形,どす
195 助動詞,*,*,*,特殊・デス,基本形,ッス
196 助動詞,*,*,*,特殊・デス,基本形,デス
197 助動詞,*,*,*,特殊・デス,基本形,ドス
198 助動詞,*,*,*,特殊・デス,未然形,っす
199 助動詞,*,*,*,特殊・デス,未然形,でぇす
200 助動詞,*,*,*,特殊・デス,未然形,です
201 助動詞,*,*,*,特殊・デス,未然形,でっす
202 助動詞,*,*,*,特殊・デス,未然形,でーす
203 助動詞,*,*,*,特殊・デス,未然形,で～す
204 助動詞,*,*,*,特殊・デス,未然形,どす
205 助動詞,*,*,*,特殊・デス,未然形,ッス
206 助動詞,*,*,*,特殊・デス,連用形,っす
207 助動詞,*,*,*,特殊・デス,連用形,でぇす
208 助動詞,*,*,*,特殊・デス,連用形,です
209 助動詞,*,*,*,特殊・デス,連用形,でっす
210 助動詞,*,*,*,特殊・デス,連用形,でーす
211 助動詞,*,*,*,特殊・デス,連用形,で～す
212 助動詞,*,*,*,特殊・デス,連用形,どす
213 助動詞,*,*,*,特殊・ナイ,ガル接続,ない
214 助動詞,*,*,*,特殊・ナイ,仮定形,ない
215 助動詞,*,*,*,特殊・ナイ,仮定縮約１,ない
216 助動詞,*,*,*,特殊・ナイ,仮定縮約２,ない
217 助動詞,*,*,*,特殊・ナイ,体言接続,ない
218 助動詞,*,*,*,特殊・ナイ,命令ｅ,ない
219 助動詞,*,*,*,特殊・ナイ,基本形,なぁい
220 助動詞,*,*,*,特殊・ナイ,基本形,ない
221 助動詞,*,*,*,特殊・ナイ,基本形,なーい
222 助動詞,*,*,*,特殊・ナイ,基本形,な～い
223 助動詞,*,*,*,特殊・ナイ,文語基本形,ない
224 助動詞,*,*,*,特殊・ナイ,未然ウ接続,ない
225 助動詞,*,*,*,特殊・ナイ,未然ヌ接続,ない
226 助動詞,*,*,*,特殊・ナイ,連用ゴザイ接続,ない
227 助動詞,*,*,*,特殊・ナイ,連用タ接続,ない
228 助動詞,*,*,*,特殊・ナイ,連用テ接続,ない
229 助動詞,*,*,*,特殊・ナイ,連用デ接続,ない
230 助動詞,*,*,*,特殊・ナイ,音便基本形,ない
231 助動詞,*,*,*,特殊・ヌ,仮定形,ぬ
232 助動詞,*,*,*,特殊・ヌ,体言接続,ぬ
233 助動詞,*,*,*,特殊・ヌ,基本形,ぬ
234 助動詞,*,*,*,特殊・ヌ,文語基本形,ぬ
235 助動詞,*,*,*,特殊・ヌ,連用ニ接続,ぬ
236 助動詞,*,*,*,特殊・ヌ,連用形,ぬ
237 助動詞,*,*,*,特殊・マス,仮定形,まぁす
238 助動詞,*,*,*,特殊・マス,仮定形,ます
239 助動詞,*,*,*,特殊・マス,仮定形,まっす
240 助動詞,*,*,*,特殊・マス,仮定形,まーす
241 助動詞,*,*,*,特殊・マス,仮定形,ま～す
242 助動詞,*,*,*,特殊・マス,仮定形,やす
243 助動詞,*,*,*,特殊・マス,命令ｅ,まぁす
244 助動詞,*,*,*,特殊・マス,命令ｅ,ます
245 助動詞,*,*,*,特殊・マス,命令ｅ,まっす
246 助動詞,*,*,*,特殊・マス,命令ｅ,まーす
247 助動詞,*,*,*,特殊・マス,命令ｅ,ま～す
248 助動詞,*,*,*,特殊・マス,命令ｅ,やす
249 助動詞,*,*,*,特殊・マス,命令ｉ,まぁす
250 助動詞,*,*,*,特殊・マス,命令ｉ,ます
251 助動詞,*,*,*,特殊・マス,命令ｉ,まっす
252 助動詞,*,*,*,特殊・マス,命令ｉ,まーす
253 助動詞,*,*,*,特殊・マス,命令ｉ,ま～す
254 助動詞,*,*,*,特殊・マス,命令ｉ,やす
255 助動詞,*,*,*,特殊・マス,基本形,まぁす
256 助動詞,*,*,*,特殊・マス,基本形,ます
257 助動詞,*,*,*,特殊・マス,基本形,まっす
258 助動詞,*,*,*,特殊・マス,基本形,まーす
259 助動詞,*,*,*,特殊・マス,基本形,ま～す
260 助動詞,*,*,*,特殊・マス,基本形,やす
261 助動詞,*,*,*,特殊・マス,未然ウ接続,まぁす
262 助動詞,*,*,*,特殊・マス,未然ウ接続,ます
263 助動詞,*,*,*,特殊・マス,未然ウ接続,まっす
264 助動詞,*,*,*,特殊・マス,未然ウ接続,まーす
265 助動詞,*,*,*,特殊・マス,未然ウ接続,ま～す
266 助動詞,*,*,*,特殊・マス,未然ウ接続,やす
267 助動詞,*,*,*,特殊・マス,未然形,まぁす
268 助動詞,*,*,*,特殊・マス,未然形,ます
269 助動詞,*,*,*,特殊・マス,未然形,ますー
270 助動詞,*,*,*,特殊・マス,未然形,ます～
271 助動詞,*,*,*,特殊・マス,未然形,まっす
272 助動詞,*,*,*,特殊・マス,未然形,まーす
273 助動詞,*,*,*,特殊・マス,未然形,ま～す
274 助動詞,*,*,*,特殊・マス,未然形,やす
275 助動詞,*,*,*,特殊・マス,連用形,まぁす
276 助動詞,*,*,*,特殊・マス,連用形,ます
277 助動詞,*,*,*,特殊・マス,連用形,まっす
278 助動詞,*,*,*,特殊・マス,連用形,まーす
279 助動詞,*,*,*,特殊・マス,連用形,ま～す
280 助動詞,*,*,*,特殊・マス,連用形,やす
281 助動詞,*,*,*,特殊・ヤ,基本形,や
282 助動詞,*,*,*,特殊・ヤ,未然形,や
283 助動詞,*,*,*,特殊・ヤ,連用形,や
284 助詞,並立助詞,*,*,*,*,たり
285 助詞,並立助詞,*,*,*,*,だの
286 助詞,並立助詞,*,*,*,*,だり
287 助詞,並立助詞,*,*,*,*,と
288 助詞,並立助詞,*,*,*,*,とか
289 助詞,並立助詞,*,*,*,*,なり
290 助詞,並立助詞,*,*,*,*,や
291 助詞,並立助詞,*,*,*,*,やら
292 助詞,並立助詞,*,*,*,*,トカ
293 助詞,係助詞,*,*,*,*,こそ
294 助詞,係助詞,*,*,*,*,さえ
295 助詞,係助詞,*,*,*,*,しか
296 助詞,係助詞,*,*,*,*,すら
297 助詞,係助詞,*,*,*,*,ぞ
298 助詞,係助詞,*,*,*,*,っきゃ
299 助詞,係助詞,*,*,*,*,は
300 助詞,係助詞,*,*,*,*,も
301 助詞,係助詞,*,*,*,*,や
302 助詞,係助詞,*,*,*,*,やいかに
303 助詞,係助詞,*,*,*,*,や如何に
304 助詞,副助詞,*,*,*,*,かも
305 助詞,副助詞,*,*,*,*,くらい
306 助詞,副助詞,*,*,*,*,ぐらい
307 助詞,副助詞,*,*,*,*,しも
308 助詞,副助詞,*,*,*,*,じゃ
309 助詞,副助詞,*,*,*,*,じゃあ
310 助詞,副助詞,*,*,*,*,じゃァ
311 助詞,副助詞,*,*,*,*,ずつ
312 助詞,副助詞,*,*,*,*,だけ
313 助詞,副助詞,*,*,*,*,だって
314 助詞,副助詞,*,*,*,*,だに
315 助詞,副助詞,*,*,*,*,でも
316 助詞,副助詞,*,*,*,*,とも
317 助詞,副助詞,*,*,*,*,なぞ
318 助詞,副助詞,*,*,*,*,など
319 助詞,副助詞,*,*,*,*,なり
320 助詞,副助詞,*,*,*,*,なんか
321 助詞,副助詞,*,*,*,*,なんざ
322 助詞,副助詞,*,*,*,*,なんぞ
323 助詞,副助詞,*,*,*,*,なんて
324 助詞,副助詞,*,*,*,*,のみ
325 助詞,副助詞,*,*,*,*,ばかし
326 助詞,副助詞,*,*,*,*,ばかり
327 助詞,副助詞,*,*,*,*,ばっか
328 助詞,副助詞,*,*,*,*,ばっかり
329 助詞,副助詞,*,*,*,*,ほど
330 助詞,副助詞,*,*,*,*,まで
331 助詞,副助詞,*,*,*,*,やら
332 助詞,副助詞,*,*,*,*,ダケ
333 助詞,副助詞,*,*,*,*,ナド
334 助詞,副助詞,*,*,*,*,ナンゾ
335 助詞,副助詞,*,*,*,*,ナンテ
336 助詞,副助詞,*,*,*,*,バカリ
337 助詞,副助詞,*,*,*,*,バッカリ
338 助詞,副助詞,*,*,*,*,マデ
339 助詞,副助詞,*,*,*,*,程
340 助詞,副助詞,*,*,*,*,迄
341 助詞,副助詞／並立助詞／終助詞,*,*,*,*,か
342 助詞,副詞化,*,*,*,*,と
343 助詞,副詞化,*,*,*,*,に
344 助詞,助詞連続,*,*,*,*,はね
345 助詞,接続助詞,*,*,*,*,および
346 助詞,接続助詞,*,*,*,*,から
347 助詞,接続助詞,*,*,*,*,からには
348 助詞,接続助詞,*,*,*,*,が
349 助詞,接続助詞,*,*,*,*,がてら
350 助詞,接続助詞,*,*,*,*,けど
351 助詞,接続助詞,*,*,*,*,けども
352 助詞,接続助詞,*,*,*,*,けれど
353 助詞,接続助詞,*,*,*,*,けれども
354 助詞,接続助詞,*,*,*,*,さかい
355 助詞,接続助詞,*,*,*,*,し
356 助詞,接続助詞,*,*,*,*,じゃ
357 助詞,接続助詞,*,*,*,*,たって
358 助詞,接続助詞,*,*,*,*,ちゃ
359 助詞,接続助詞,*,*,*,*,ちゃあ
360 助詞,接続助詞,*,*,*,*,つつ
361 助詞,接続助詞,*,*,*,*,て
362 助詞,接続助詞,*,*,*,*,で
363 助詞,接続助詞,*,*,*,*,と
364 助詞,接続助詞,*,*,*,*,とも
365 助詞,接続助詞,*,*,*,*,ど
366 助詞,接続助詞,*,*,*,*,どころか
367 助詞,接続助詞,*,*,*,*,ども
368 助詞,接続助詞,*,*,*,*,ながら
369 助詞,接続助詞,*,*,*,*,なり
370 助詞,接続助詞,*,*,*,*,につけ
371 助詞,接続助詞,*,*,*,*,にも
372 助詞,接続助詞,*,*,*,*,ので
373 助詞,接続助詞,*,*,*,*,のに
374 助詞,接続助詞,*,*,*,*,ば
375 助詞,接続助詞,*,*,*,*,ものの
376 助詞,接続助詞,*,*,*,*,や
377 助詞,接続助詞,*,*,*,*,やいなや
378 助詞,接続助詞,*,*,*,*,んで
379 助詞,接続助詞,*,*,*,*,ケド
380 助詞,接続助詞,一般,*,*,*,に
381 助詞,格助詞,一般,*,*,*,から
382 助詞,格助詞,一般,*,*,*,が
383 助詞,格助詞,一般,*,*,*,で
384 助詞,格助詞,一般,*,*,*,と
385 助詞,格助詞,一般,*,*,*,に
386 助詞,格助詞,一般,*,*,*,にて
387 助詞,格助詞,一般,*,*,*,の
388 助詞,格助詞,一般,*,*,*,へ
389 助詞,格助詞,一般,*,*,*,もの
390 助詞,格助詞,一般,*,*,*,よか
391 助詞,格助詞,一般,*,*,*,より
392 助詞,格助詞,一般,*,*,*,を
393 助詞,格助詞,一般,*,*,*,ん
394 助詞,格助詞,一般,*,*,*,デ
395 助詞,格助詞,一般,*,*,*,ノ
396 助詞,格助詞,一般,*,*,*,ヘ
397 助詞,格助詞,一般,*,*,*,ヲ
398 助詞,格助詞,一般,*,*,*,之
399 助詞,格助詞,引用,*,*,*,っと
400 助詞,格助詞,引用,*,*,*,と
401 助詞,格助詞,引用,*,*,*,ット
402 助詞,格助詞,意志,*,*,*,と
403 助詞,格助詞,連語,*,*,*,じゃ
404 助詞,格助詞,連語,*,*,*,って
405 助詞,格助詞,連語,*,*,*,っていう
406 助詞,格助詞,連語,*,*,*,ってな
407 助詞,格助詞,連語,*,*,*,て
408 助詞,格助詞,連語,*,*,*,について
409 助詞,格助詞,連語,*,*,*,にとって
410 助詞,特殊,*,*,*,*,かな
411 助詞,特殊,*,*,*,*,けむ
412 助詞,特殊,*,*,*,*,に
413 助詞,特殊,*,*,*,*,にゃ
414 助詞,特殊,*,*,*,*,ん
415 助詞,特殊,*,*,*,*,ニャ
416 助詞,終助詞,*,*,*,*,うぃる
417 助詞,終助詞,*,*,*,*,お
418 助詞,終助詞,*,*,*,*,かぁ
419 助詞,終助詞,*,*,*,*,かい
420 助詞,終助詞,*,*,*,*,かしら
421 助詞,終助詞,*,*,*,*,かな
422 助詞,終助詞,*,*,*,*,かね
423 助詞,終助詞,*,*,*,*,け
424 助詞,終助詞,*,*,*,*,さ
425 助詞,終助詞,*,*,*,*,ぜ
426 助詞,終助詞,*,*,*,*,ぞ
427 助詞,終助詞,*,*,*,*,だって
428 助詞,終助詞,*,*,*,*,だん
429 助詞,終助詞,*,*,*,*,っけ
430 助詞,終助詞,*,*,*,*,てん
431 助詞,終助詞,*,*,*,*,で
432 助詞,終助詞,*,*,*,*,な
433 助詞,終助詞,*,*,*,*,なぁ
434 助詞,終助詞,*,*,*,*,なぁー
435 助詞,終助詞,*,*,*,*,なあ
436 助詞,終助詞,*,*,*,*,なう
437 助詞,終助詞,*,*,*,*,なァ
438 助詞,終助詞,*,*,*,*,なー
439 助詞,終助詞,*,*,*,*,ね
440 助詞,終助詞,*,*,*,*,ねぇ
441 助詞,終助詞,*,*,*,*,ねえ
442 助詞,終助詞,*,*,*,*,ねん
443 助詞,終助詞,*,*,*,*,ねェ
444 助詞,終助詞,*,*,*,*,ねエ
445 助詞,終助詞,*,*,*,*,ねッ
446 助詞,終助詞,*,*,*,*,ねー
447 助詞,終助詞,*,*,*,*,の
448 助詞,終助詞,*,*,*,*,のう
449 助詞,終助詞,*,*,*,*,のなんの
450 助詞,終助詞,*,*,*,*,のなんのって
451 助詞,終助詞,*,*,*,*,べ
452 助詞,終助詞,*,*,*,*,もん
453 助詞,終助詞,*,*,*,*,や
454 助詞,終助詞,*,*,*,*,やら
455 助詞,終助詞,*,*,*,*,よ
456 助詞,終助詞,*,*,*,*,よう
457 助詞,終助詞,*,*,*,*,よー
458 助詞,終助詞,*,*,*,*,わ
459 助詞,終助詞,*,*,*,*,わい
460 助詞,終助詞,*,*,*,*,わず
461 助詞,終助詞,*,*,*,*,ん
462 助詞,終助詞,*,*,*,*,ナ
463 助詞,終助詞,*,*,*,*,ナア
464 助詞,終助詞,*,*,*,*,ネ
465 助詞,終助詞,*,*,*,*,ネェ
466 助詞,終助詞,*,*,*,*,ヨ
467 助詞,終助詞,*,*,*,*,ヨー
468 助詞,終助詞,*,*,*,*,ワ
469 助詞,連体化,*,*,*,*,の
470 動詞,接尾,*,*,一段,仮定形,させる
471 動詞,接尾,*,*,一段,仮定形,しめる
472 動詞,接尾,*,*,一段,仮定形,せる
473 動詞,接尾,*,*,一段,仮定形,られる
474 動詞,接尾,*,*,一段,仮定形,れる
475 動詞,接尾,*,*,一段,仮定縮約１,させる
476 動詞,接尾,*,*,一段,仮定縮約１,しめる
477 動詞,接尾,*,*,一段,仮定縮約１,せる
478 動詞,接尾,*,*,一段,仮定縮約１,られる
479 動詞,接尾,*,*,一段,仮定縮約１,れる
480 動詞,接尾,*,*,一段,体言接続特殊,させる
481 動詞,接尾,*,*,一段,体言接続特殊,しめる
482 動詞,接尾,*,*,一段,体言接続特殊,せる
483 動詞,接尾,*,*,一段,体言接続特殊,られる
484 動詞,接尾,*,*,一段,体言接続特殊,れる
485 動詞,接尾,*,*,一段,命令ｒｏ,させる
486 動詞,接尾,*,*,一段,命令ｒｏ,しめる
487 動詞,接尾,*,*,一段,命令ｒｏ,せる
488 動詞,接尾,*,*,一段,命令ｒｏ,られる
489 動詞,接尾,*,*,一段,命令ｒｏ,れる
490 動詞,接尾,*,*,一段,命令ｙｏ,させる
491 動詞,接尾,*,*,一段,命令ｙｏ,しめる
492 動詞,接尾,*,*,一段,命令ｙｏ,せる
493 動詞,接尾,*,*,一段,命令ｙｏ,られる
494 動詞,接尾,*,*,一段,命令ｙｏ,れる
495 動詞,接尾,*,*,一段,基本形,させる
496 動詞,接尾,*,*,一段,基本形,しめる
497 動詞,接尾,*,*,一段,基本形,せる
498 動詞,接尾,*,*,一段,基本形,られる
499 動詞,接尾,*,*,一段,基本形,れる
500 動詞,接尾,*,*,一段,未然ウ接続,させる
501 動詞,接尾,*,*,一段,未然ウ接続,しめる
502 動詞,接尾,*,*,一段,未然ウ接続,せる
503 動詞,接尾,*,*,一段,未然ウ接続,られる
504 動詞,接尾,*,*,一段,未然ウ接続,れる
505 動詞,接尾,*,*,一段,未然形,させる
506 動詞,接尾,*,*,一段,未然形,しめる
507 動詞,接尾,*,*,一段,未然形,せる
508 動詞,接尾,*,*,一段,未然形,られる
509 動詞,接尾,*,*,一段,未然形,れる
510 動詞,接尾,*,*,一段,連用形,させる
511 動詞,接尾,*,*,一段,連用形,しめる
512 動詞,接尾,*,*,一段,連用形,せる
513 動詞,接尾,*,*,一段,連用形,られる
514 動詞,接尾,*,*,一段,連用形,れる
515 動詞,接尾,*,*,五段・サ行,仮定形,さす
516 動詞,接尾,*,*,五段・サ行,仮定形,す
517 動詞,接尾,*,*,五段・サ行,仮定形,剳す
518 動詞,接尾,*,*,五段・サ行,仮定形,扠す
519 動詞,接尾,*,*,五段・サ行,仮定形,扨す
520 動詞,接尾,*,*,五段・サ行,仮定形,捺す
521 動詞,接尾,*,*,五段・サ行,仮定形,箚す
522 動詞,接尾,*,*,五段・サ行,仮定形,點す
523 動詞,接尾,*,*,五段・サ行,仮定縮約１,さす
524 動詞,接尾,*,*,五段・サ行,仮定縮約１,す
525 動詞,接尾,*,*,五段・サ行,仮定縮約１,剳す
526 動詞,接尾,*,*,五段・サ行,仮定縮約１,扠す
527 動詞,接尾,*,*,五段・サ行,仮定縮約１,扨す
528 動詞,接尾,*,*,五段・サ行,仮定縮約１,捺す
529 動詞,接尾,*,*,五段・サ行,仮定縮約１,箚す
530 動詞,接尾,*,*,五段・サ行,仮定縮約１,點す
531 動詞,接尾,*,*,五段・サ行,命令ｅ,さす
532 動詞,接尾,*,*,五段・サ行,命令ｅ,す
533 動詞,接尾,*,*,五段・サ行,命令ｅ,剳す
534 動詞,接尾,*,*,五段・サ行,命令ｅ,扠す
535 動詞,接尾,*,*,五段・サ行,命令ｅ,扨す
536 動詞,接尾,*,*,五段・サ行,命令ｅ,捺す
537 動詞,接尾,*,*,五段・サ行,命令ｅ,箚す
538 動詞,接尾,*,*,五段・サ行,命令ｅ,點す
539 動詞,接尾,*,*,五段・サ行,基本形,さす
540 動詞,接尾,*,*,五段・サ行,基本形,す
541 動詞,接尾,*,*,五段・サ行,基本形,剳す
542 動詞,接尾,*,*,五段・サ行,基本形,扠す
543 動詞,接尾,*,*,五段・サ行,基本形,扨す
544 動詞,接尾,*,*,五段・サ行,基本形,捺す
545 動詞,接尾,*,*,五段・サ行,基本形,箚す
546 動詞,接尾,*,*,五段・サ行,基本形,點す
547 動詞,接尾,*,*,五段・サ行,未然ウ接続,さす
548 動詞,接尾,*,*,五段・サ行,未然ウ接続,す
549 動詞,接尾,*,*,五段・サ行,未然ウ接続,剳す
550 動詞,接尾,*,*,五段・サ行,未然ウ接続,扠す
551 動詞,接尾,*,*,五段・サ行,未然ウ接続,扨す
552 動詞,接尾,*,*,五段・サ行,未然ウ接続,捺す
553 動詞,接尾,*,*,五段・サ行,未然ウ接続,箚す
554 動詞,接尾,*,*,五段・サ行,未然ウ接続,點す
555 動詞,接尾,*,*,五段・サ行,未然形,さす
556 動詞,接尾,*,*,五段・サ行,未然形,す
557 動詞,接尾,*,*,五段・サ行,未然形,剳す
558 動詞,接尾,*,*,五段・サ行,未然形,扠す
559 動詞,接尾,*,*,五段・サ行,未然形,扨す
560 動詞,接尾,*,*,五段・サ行,未然形,捺す
561 動詞,接尾,*,*,五段・サ行,未然形,箚す
562 動詞,接尾,*,*,五段・サ行,未然形,點す
563 動詞,接尾,*,*,五段・サ行,連用形,さす
564 動詞,接尾,*,*,五段・サ行,連用形,す
565 動詞,接尾,*,*,五段・サ行,連用形,剳す
566 動詞,接尾,*,*,五段・サ行,連用形,扠す
567 動詞,接尾,*,*,五段・サ行,連用形,扨す
568 動詞,接尾,*,*,五段・サ行,連用形,捺す
569 動詞,接尾,*,*,五段・サ行,連用形,箚す
570 動詞,接尾,*,*,五段・サ行,連用形,點す
571 動詞,接尾,*,*,五段・ラ行,仮定形,がかる
572 動詞,接尾,*,*,五段・ラ行,仮定形,がる
573 動詞,接尾,*,*,五段・ラ行,仮定形,掛かる
574 動詞,接尾,*,*,五段・ラ行,仮定縮約１,がかる
575 動詞,接尾,*,*,五段・ラ行,仮定縮約１,がる
576 動詞,接尾,*,*,五段・ラ行,仮定縮約１,掛かる
577 動詞,接尾,*,*,五段・ラ行,体言接続特殊,がかる
578 動詞,接尾,*,*,五段・ラ行,体言接続特殊,がる
579 動詞,接尾,*,*,五段・ラ行,体言接続特殊,掛かる
580 動詞,接尾,*,*,五段・ラ行,体言接続特殊２,がかる
581 動詞,接尾,*,*,五段・ラ行,体言接続特殊２,がる
582 動詞,接尾,*,*,五段・ラ行,命令ｅ,がかる
583 動詞,接尾,*,*,五段・ラ行,命令ｅ,がる
584 動詞,接尾,*,*,五段・ラ行,命令ｅ,掛かる
585 動詞,接尾,*,*,五段・ラ行,基本形,がかる
586 動詞,接尾,*,*,五段・ラ行,基本形,がる
587 動詞,接尾,*,*,五段・ラ行,基本形,掛かる
588 動詞,接尾,*,*,五段・ラ行,未然ウ接続,がかる
589 動詞,接尾,*,*,五段・ラ行,未然ウ接続,がる
590 動詞,接尾,*,*,五段・ラ行,未然ウ接続,掛かる
591 動詞,接尾,*,*,五段・ラ行,未然形,がかる
592 動詞,接尾,*,*,五段・ラ行,未然形,がる
593 動詞,接尾,*,*,五段・ラ行,未然形,掛かる
594 動詞,接尾,*,*,五段・ラ行,未然特殊,がかる
595 動詞,接尾,*,*,五段・ラ行,未然特殊,がる
596 動詞,接尾,*,*,五段・ラ行,未然特殊,掛かる
597 動詞,接尾,*,*,五段・ラ行,連用タ接続,がかる
598 動詞,接尾,*,*,五段・ラ行,連用タ接続,がる
599 動詞,接尾,*,*,五段・ラ行,連用タ接続,掛かる
600 動詞,接尾,*,*,五段・ラ行,連用形,がかる
601 動詞,接尾,*,*,五段・ラ行,連用形,がる
602 動詞,接尾,*,*,五段・ラ行,連用形,掛かる
603 動詞,接尾,*,*,五段・ラ行,連用形,狩り
604 動詞,自立,*,*,*,体言接続特殊２,*
605 動詞,自立,*,*,*,文語基本形,*,
606 動詞,自立,*,*,カ変・クル,丁寧連用形,*
607 動詞,自立,*,*,カ変・クル,仮定形,*
608 動詞,自立,*,*,カ変・クル,仮定縮約１,*
609 動詞,自立,*,*,カ変・クル,体言接続特殊,*
610 動詞,自立,*,*,カ変・クル,命令ｉ,*
611 動詞,自立,*,*,カ変・クル,命令ｙｏ,*
612 動詞,自立,*,*,カ変・クル,基本形,*
613 動詞,自立,*,*,カ変・クル,未然ウ接続,*
614 動詞,自立,*,*,カ変・クル,未然形,*
615 動詞,自立,*,*,カ変・クル,連用形,*
616 動詞,自立,*,*,カ変・来ル,丁寧連用形,来る
617 動詞,自立,*,*,カ変・来ル,仮定形,*
618 動詞,自立,*,*,カ変・来ル,仮定形,来る
619 動詞,自立,*,*,カ変・来ル,仮定縮約１,*
620 動詞,自立,*,*,カ変・来ル,仮定縮約１,来る
621 動詞,自立,*,*,カ変・来ル,体言接続特殊,*
622 動詞,自立,*,*,カ変・来ル,体言接続特殊,来る
623 動詞,自立,*,*,カ変・来ル,体言接続特殊２,来る
624 動詞,自立,*,*,カ変・来ル,命令ｉ,*
625 動詞,自立,*,*,カ変・来ル,命令ｉ,来る
626 動詞,自立,*,*,カ変・来ル,命令ｙｏ,*
627 動詞,自立,*,*,カ変・来ル,命令ｙｏ,来る
628 動詞,自立,*,*,カ変・来ル,基本形,*
629 動詞,自立,*,*,カ変・来ル,基本形,来る
630 動詞,自立,*,*,カ変・来ル,未然ウ接続,*
631 動詞,自立,*,*,カ変・来ル,未然ウ接続,来る
632 動詞,自立,*,*,カ変・来ル,未然形,*
633 動詞,自立,*,*,カ変・来ル,未然形,来る
634 動詞,自立,*,*,カ変・来ル,連用形,*
635 動詞,自立,*,*,カ変・来ル,連用形,来る
636 動詞,自立,*,*,サ変,仮定形,*
637 動詞,自立,*,*,サ変,仮定形,3
638 動詞,自立,*,*,サ変,仮定形,4
639 動詞,自立,*,*,サ変,仮定形,5
640 動詞,自立,*,*,サ変,仮定形,6
641 動詞,自立,*,*,サ変,仮定形,7
642 動詞,自立,*,*,サ変,仮定形,8
643 動詞,自立,*,*,サ変,仮定縮約１,*
644 動詞,自立,*,*,サ変,仮定縮約１,3
645 動詞,自立,*,*,サ変,仮定縮約１,4
646 動詞,自立,*,*,サ変,仮定縮約１,5
647 動詞,自立,*,*,サ変,仮定縮約１,6
648 動詞,自立,*,*,サ変,仮定縮約１,7
649 動詞,自立,*,*,サ変,仮定縮約１,8
650 動詞,自立,*,*,サ変,命令ｒｏ,*
651 動詞,自立,*,*,サ変,命令ｒｏ,3
652 動詞,自立,*,*,サ変,命令ｒｏ,4
653 動詞,自立,*,*,サ変,命令ｒｏ,5
654 動詞,自立,*,*,サ変,命令ｒｏ,6
655 動詞,自立,*,*,サ変,命令ｒｏ,7
656 動詞,自立,*,*,サ変,命令ｒｏ,8
657 動詞,自立,*,*,サ変,命令ｙｏ,*
658 動詞,自立,*,*,サ変,命令ｙｏ,3
659 動詞,自立,*,*,サ変,命令ｙｏ,4
660 動詞,自立,*,*,サ変,命令ｙｏ,5
661 動詞,自立,*,*,サ変,命令ｙｏ,6
662 動詞,自立,*,*,サ変,命令ｙｏ,7
663 動詞,自立,*,*,サ変,命令ｙｏ,8
664 動詞,自立,*,*,サ変,基本形,*
665 動詞,自立,*,*,サ変,基本形,3
666 動詞,自立,*,*,サ変,基本形,4
667 動詞,自立,*,*,サ変,基本形,5
668 動詞,自立,*,*,サ変,基本形,6
669 動詞,自立,*,*,サ変,基本形,7
670 動詞,自立,*,*,サ変,基本形,8
671 動詞,自立,*,*,サ変,文語基本形,*
672 動詞,自立,*,*,サ変,文語基本形,3
673 動詞,自立,*,*,サ変,文語基本形,4
674 動詞,自立,*,*,サ変,文語基本形,5
675 動詞,自立,*,*,サ変,文語基本形,6
676 動詞,自立,*,*,サ変,文語基本形,7
677 動詞,自立,*,*,サ変,文語基本形,8
678 動詞,自立,*,*,サ変,未然ウ接続,*
679 動詞,自立,*,*,サ変,未然ウ接続,3
680 動詞,自立,*,*,サ変,未然ウ接続,4
681 動詞,自立,*,*,サ変,未然ウ接続,5
682 動詞,自立,*,*,サ変,未然ウ接続,6
683 動詞,自立,*,*,サ変,未然ウ接続,7
684 動詞,自立,*,*,サ変,未然ウ接続,8
685 動詞,自立,*,*,サ変,未然レル接続,*
686 動詞,自立,*,*,サ変,未然レル接続,3
687 動詞,自立,*,*,サ変,未然レル接続,4
688 動詞,自立,*,*,サ変,未然レル接続,5
689 動詞,自立,*,*,サ変,未然レル接続,6
690 動詞,自立,*,*,サ変,未然レル接続,7
691 動詞,自立,*,*,サ変,未然レル接続,8
692 動詞,自立,*,*,サ変,未然形,*
693 動詞,自立,*,*,サ変,未然形,3
694 動詞,自立,*,*,サ変,未然形,4
695 動詞,自立,*,*,サ変,未然形,5
696 動詞,自立,*,*,サ変,未然形,6
697 動詞,自立,*,*,サ変,未然形,7
698 動詞,自立,*,*,サ変,未然形,8
699 動詞,自立,*,*,サ変,連用形,8
700 動詞,自立,*,*,サ変・スル,丁寧連用形,*
701 動詞,自立,*,*,サ変・スル,仮定形,*
702 動詞,自立,*,*,サ変・スル,仮定縮約１,*
703 動詞,自立,*,*,サ変・スル,体言接続特殊,*
704 動詞,自立,*,*,サ変・スル,命令ｉ,*
705 動詞,自立,*,*,サ変・スル,命令ｒｏ,*
706 動詞,自立,*,*,サ変・スル,命令ｙｏ,*
707 動詞,自立,*,*,サ変・スル,基本形,*
708 動詞,自立,*,*,サ変・スル,未然ウ接続,*
709 動詞,自立,*,*,サ変・スル,未然ヌ接続,*
710 動詞,自立,*,*,サ変・スル,未然レル接続,*
711 動詞,自立,*,*,サ変・スル,未然形,*
712 動詞,自立,*,*,サ変・スル,連用形,*
713 動詞,自立,*,*,ラ変,仮定形,*
714 動詞,自立,*,*,ラ変,体言接続,*
715 動詞,自立,*,*,ラ変,命令ｅ,*
716 動詞,自立,*,*,ラ変,基本形,*
717 動詞,自立,*,*,ラ変,未然形,*
718 動詞,自立,*,*,ラ変,連用形,*
719 動詞,自立,*,*,一段,丁寧連用形,*
720 動詞,自立,*,*,一段,丁寧連用形,1
721 動詞,自立,*,*,一段,丁寧連用形,2
722 動詞,自立,*,*,一段,丁寧連用形,3
723 動詞,自立,*,*,一段,丁寧連用形,4
724 動詞,自立,*,*,一段,丁寧連用形,5
725 動詞,自立,*,*,一段,丁寧連用形,6
726 動詞,自立,*,*,一段,丁寧連用形,7
727 動詞,自立,*,*,一段,丁寧連用形,8
728 動詞,自立,*,*,一段,丁寧連用形,いる
729 動詞,自立,*,*,一段,丁寧連用形,おける
730 動詞,自立,*,*,一段,丁寧連用形,できる
731 動詞,自立,*,*,一段,丁寧連用形,出来る
732 動詞,自立,*,*,一段,仮定形,*
733 動詞,自立,*,*,一段,仮定形,1
734 動詞,自立,*,*,一段,仮定形,2
735 動詞,自立,*,*,一段,仮定形,3
736 動詞,自立,*,*,一段,仮定形,4
737 動詞,自立,*,*,一段,仮定形,5
738 動詞,自立,*,*,一段,仮定形,6
739 動詞,自立,*,*,一段,仮定形,7
740 動詞,自立,*,*,一段,仮定形,8
741 動詞,自立,*,*,一段,仮定形,いる
742 動詞,自立,*,*,一段,仮定形,おける
743 動詞,自立,*,*,一段,仮定形,できる
744 動詞,自立,*,*,一段,仮定形,出来る
745 動詞,自立,*,*,一段,仮定縮約１,*
746 動詞,自立,*,*,一段,仮定縮約１,1
747 動詞,自立,*,*,一段,仮定縮約１,2
748 動詞,自立,*,*,一段,仮定縮約１,3
749 動詞,自立,*,*,一段,仮定縮約１,4
750 動詞,自立,*,*,一段,仮定縮約１,5
751 動詞,自立,*,*,一段,仮定縮約１,6
752 動詞,自立,*,*,一段,仮定縮約１,7
753 動詞,自立,*,*,一段,仮定縮約１,8
754 動詞,自立,*,*,一段,仮定縮約１,いる
755 動詞,自立,*,*,一段,仮定縮約１,おける
756 動詞,自立,*,*,一段,仮定縮約１,できる
757 動詞,自立,*,*,一段,仮定縮約１,出来る
758 動詞,自立,*,*,一段,体言接続特殊,*
759 動詞,自立,*,*,一段,体言接続特殊,1
760 動詞,自立,*,*,一段,体言接続特殊,2
761 動詞,自立,*,*,一段,体言接続特殊,3
762 動詞,自立,*,*,一段,体言接続特殊,4
763 動詞,自立,*,*,一段,体言接続特殊,5
764 動詞,自立,*,*,一段,体言接続特殊,6
765 動詞,自立,*,*,一段,体言接続特殊,7
766 動詞,自立,*,*,一段,体言接続特殊,8
767 動詞,自立,*,*,一段,体言接続特殊,いる
768 動詞,自立,*,*,一段,体言接続特殊,おける
769 動詞,自立,*,*,一段,体言接続特殊,できる
770 動詞,自立,*,*,一段,体言接続特殊,出来る
771 動詞,自立,*,*,一段,命令ｒｏ,*
772 動詞,自立,*,*,一段,命令ｒｏ,1
773 動詞,自立,*,*,一段,命令ｒｏ,2
774 動詞,自立,*,*,一段,命令ｒｏ,3
775 動詞,自立,*,*,一段,命令ｒｏ,4
776 動詞,自立,*,*,一段,命令ｒｏ,5
777 動詞,自立,*,*,一段,命令ｒｏ,6
778 動詞,自立,*,*,一段,命令ｒｏ,7
779 動詞,自立,*,*,一段,命令ｒｏ,8
780 動詞,自立,*,*,一段,命令ｒｏ,いる
781 動詞,自立,*,*,一段,命令ｒｏ,おける
782 動詞,自立,*,*,一段,命令ｒｏ,できる
783 動詞,自立,*,*,一段,命令ｒｏ,出来る
784 動詞,自立,*,*,一段,命令ｙｏ,*
785 動詞,自立,*,*,一段,命令ｙｏ,1
786 動詞,自立,*,*,一段,命令ｙｏ,2
787 動詞,自立,*,*,一段,命令ｙｏ,3
788 動詞,自立,*,*,一段,命令ｙｏ,4
789 動詞,自立,*,*,一段,命令ｙｏ,5
790 動詞,自立,*,*,一段,命令ｙｏ,6
791 動詞,自立,*,*,一段,命令ｙｏ,7
792 動詞,自立,*,*,一段,命令ｙｏ,8
793 動詞,自立,*,*,一段,命令ｙｏ,いる
794 動詞,自立,*,*,一段,命令ｙｏ,おける
795 動詞,自立,*,*,一段,命令ｙｏ,できる
796 動詞,自立,*,*,一段,命令ｙｏ,出来る
797 動詞,自立,*,*,一段,基本形,*
798 動詞,自立,*,*,一段,基本形,1
799 動詞,自立,*,*,一段,基本形,2
800 動詞,自立,*,*,一段,基本形,3
801 動詞,自立,*,*,一段,基本形,4
802 動詞,自立,*,*,一段,基本形,5
803 動詞,自立,*,*,一段,基本形,6
804 動詞,自立,*,*,一段,基本形,7
805 動詞,自立,*,*,一段,基本形,8
806 動詞,自立,*,*,一段,基本形,いる
807 動詞,自立,*,*,一段,基本形,おける
808 動詞,自立,*,*,一段,基本形,できる
809 動詞,自立,*,*,一段,基本形,出来る
810 動詞,自立,*,*,一段,未然ウ接続,*
811 動詞,自立,*,*,一段,未然ウ接続,1
812 動詞,自立,*,*,一段,未然ウ接続,2
813 動詞,自立,*,*,一段,未然ウ接続,3
814 動詞,自立,*,*,一段,未然ウ接続,4
815 動詞,自立,*,*,一段,未然ウ接続,5
816 動詞,自立,*,*,一段,未然ウ接続,6
817 動詞,自立,*,*,一段,未然ウ接続,7
818 動詞,自立,*,*,一段,未然ウ接続,8
819 動詞,自立,*,*,一段,未然ウ接続,いる
820 動詞,自立,*,*,一段,未然ウ接続,おける
821 動詞,自立,*,*,一段,未然ウ接続,できる
822 動詞,自立,*,*,一段,未然ウ接続,出来る
823 動詞,自立,*,*,一段,未然形,*
824 動詞,自立,*,*,一段,未然形,1
825 動詞,自立,*,*,一段,未然形,2
826 動詞,自立,*,*,一段,未然形,3
827 動詞,自立,*,*,一段,未然形,4
828 動詞,自立,*,*,一段,未然形,5
829 動詞,自立,*,*,一段,未然形,6
830 動詞,自立,*,*,一段,未然形,7
831 動詞,自立,*,*,一段,未然形,8
832 動詞,自立,*,*,一段,未然形,いる
833 動詞,自立,*,*,一段,未然形,おける
834 動詞,自立,*,*,一段,未然形,できる
835 動詞,自立,*,*,一段,未然形,出来る
836 動詞,自立,*,*,一段,連用形,*
837 動詞,自立,*,*,一段,連用形,1
838 動詞,自立,*,*,一段,連用形,2
839 動詞,自立,*,*,一段,連用形,3
840 動詞,自立,*,*,一段,連用形,4
841 動詞,自立,*,*,一段,連用形,5
842 動詞,自立,*,*,一段,連用形,6
843 動詞,自立,*,*,一段,連用形,7
844 動詞,自立,*,*,一段,連用形,8
845 動詞,自立,*,*,一段,連用形,いる
846 動詞,自立,*,*,一段,連用形,おける
847 動詞,自立,*,*,一段,連用形,できる
848 動詞,自立,*,*,一段,連用形,出来る
849 動詞,自立,*,*,一段・クレル,丁寧連用形,*
850 動詞,自立,*,*,一段・クレル,仮定形,*
851 動詞,自立,*,*,一段・クレル,仮定縮約１,*
852 動詞,自立,*,*,一段・クレル,命令ｅ,*
853 動詞,自立,*,*,一段・クレル,命令ｒｏ,*
854 動詞,自立,*,*,一段・クレル,命令ｙｏ,*
855 動詞,自立,*,*,一段・クレル,基本形,*
856 動詞,自立,*,*,一段・クレル,未然ウ接続,*
857 動詞,自立,*,*,一段・クレル,未然形,*
858 動詞,自立,*,*,一段・クレル,未然特殊,*
859 動詞,自立,*,*,一段・クレル,連用形,*
860 動詞,自立,*,*,一段・得ル,仮定形,*
861 動詞,自立,*,*,一段・得ル,基本形,*
862 動詞,自立,*,*,五段・カ行促音便,丁寧連用形,行く
863 動詞,自立,*,*,五段・カ行促音便,仮定形,行く
864 動詞,自立,*,*,五段・カ行促音便,仮定縮約１,行く
865 動詞,自立,*,*,五段・カ行促音便,命令ｅ,行く
866 動詞,自立,*,*,五段・カ行促音便,基本形,行く
867 動詞,自立,*,*,五段・カ行促音便,未然ウ接続,行く
868 動詞,自立,*,*,五段・カ行促音便,未然形,行く
869 動詞,自立,*,*,五段・カ行促音便,連用タ接続,行く
870 動詞,自立,*,*,五段・カ行促音便,連用形,行く
871 動詞,自立,*,*,五段・ラ行,丁寧連用形,ある
872 動詞,自立,*,*,五段・ラ行,丁寧連用形,いる
873 動詞,自立,*,*,五段・ラ行,丁寧連用形,なる
874 動詞,自立,*,*,五段・ラ行,仮定形,ある
875 動詞,自立,*,*,五段・ラ行,仮定形,いる
876 動詞,自立,*,*,五段・ラ行,仮定形,なる
877 動詞,自立,*,*,五段・ラ行,仮定縮約１,ある
878 動詞,自立,*,*,五段・ラ行,仮定縮約１,いる
879 動詞,自立,*,*,五段・ラ行,仮定縮約１,なる
880 動詞,自立,*,*,五段・ラ行,体言接続特殊,ある
881 動詞,自立,*,*,五段・ラ行,体言接続特殊,いる
882 動詞,自立,*,*,五段・ラ行,体言接続特殊,なる
883 動詞,自立,*,*,五段・ラ行,体言接続特殊２,ある
884 動詞,自立,*,*,五段・ラ行,体言接続特殊２,いる
885 動詞,自立,*,*,五段・ラ行,体言接続特殊２,なる
886 動詞,自立,*,*,五段・ラ行,命令ｅ,ある
887 動詞,自立,*,*,五段・ラ行,命令ｅ,いる
888 動詞,自立,*,*,五段・ラ行,命令ｅ,なる
889 動詞,自立,*,*,五段・ラ行,基本形,ある
890 動詞,自立,*,*,五段・ラ行,基本形,いる
891 動詞,自立,*,*,五段・ラ行,基本形,なる
892 動詞,自立,*,*,五段・ラ行,未然ウ接続,ある
893 動詞,自立,*,*,五段・ラ行,未然ウ接続,いる
894 動詞,自立,*,*,五段・ラ行,未然ウ接続,なる
895 動詞,自立,*,*,五段・ラ行,未然形,ある
896 動詞,自立,*,*,五段・ラ行,未然形,いる
897 動詞,自立,*,*,五段・ラ行,未然形,なる
898 動詞,自立,*,*,五段・ラ行,未然特殊,ある
899 動詞,自立,*,*,五段・ラ行,未然特殊,いる
900 動詞,自立,*,*,五段・ラ行,未然特殊,なる
901 動詞,自立,*,*,五段・ラ行,連用タ接続,ある
902 動詞,自立,*,*,五段・ラ行,連用タ接続,いる
903 動詞,自立,*,*,五段・ラ行,連用タ接続,なる
904 動詞,自立,*,*,五段・ラ行,連用形,ある
905 動詞,自立,*,*,五段・ラ行,連用形,いる
906 動詞,自立,*,*,五段・ラ行,連用形,なる
907 動詞,自立,*,*,五段・ワ行促音便,丁寧連用形,*
908 動詞,自立,*,*,五段・ワ行促音便,丁寧連用形,いう
909 動詞,自立,*,*,五段・ワ行促音便,丁寧連用形,行う
910 動詞,自立,*,*,五段・ワ行促音便,丁寧連用形,言う
911 動詞,自立,*,*,五段・ワ行促音便,仮定形,*
912 動詞,自立,*,*,五段・ワ行促音便,仮定形,いう
913 動詞,自立,*,*,五段・ワ行促音便,仮定形,行う
914 動詞,自立,*,*,五段・ワ行促音便,仮定形,言う
915 動詞,自立,*,*,五段・ワ行促音便,仮定縮約１,*
916 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,*
917 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,いう
918 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,行う
919 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,言う
920 動詞,自立,*,*,五段・ワ行促音便,基本形,*
921 動詞,自立,*,*,五段・ワ行促音便,基本形,いう
922 動詞,自立,*,*,五段・ワ行促音便,基本形,行う
923 動詞,自立,*,*,五段・ワ行促音便,基本形,言う
924 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,*
925 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,いう
926 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,行う
927 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,言う
928 動詞,自立,*,*,五段・ワ行促音便,未然形,*
929 動詞,自立,*,*,五段・ワ行促音便,未然形,いう
930 動詞,自立,*,*,五段・ワ行促音便,未然形,行う
931 動詞,自立,*,*,五段・ワ行促音便,未然形,言う
932 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,*
933 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,いう
934 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,行う
935 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,言う
936 動詞,自立,*,*,五段・ワ行促音便,連用形,*
937 動詞,自立,*,*,五段・ワ行促音便,連用形,いう
938 動詞,自立,*,*,五段・ワ行促音便,連用形,行う
939 動詞,自立,*,*,五段・ワ行促音便,連用形,言う
940 動詞,自立,*,*,五段動詞,丁寧連用形,*
941 動詞,自立,*,*,五段動詞,丁寧連用形,1
942 動詞,自立,*,*,五段動詞,丁寧連用形,3
943 動詞,自立,*,*,五段動詞,丁寧連用形,4
944 動詞,自立,*,*,五段動詞,丁寧連用形,5
945 動詞,自立,*,*,五段動詞,丁寧連用形,6
946 動詞,自立,*,*,五段動詞,丁寧連用形,7
947 動詞,自立,*,*,五段動詞,丁寧連用形,8
948 動詞,自立,*,*,五段動詞,仮定形,*
949 動詞,自立,*,*,五段動詞,仮定形,1
950 動詞,自立,*,*,五段動詞,仮定形,2
951 動詞,自立,*,*,五段動詞,仮定形,3
952 動詞,自立,*,*,五段動詞,仮定形,4
953 動詞,自立,*,*,五段動詞,仮定形,5
954 動詞,自立,*,*,五段動詞,仮定形,6
955 動詞,自立,*,*,五段動詞,仮定形,7
956 動詞,自立,*,*,五段動詞,仮定形,8
957 動詞,自立,*,*,五段動詞,仮定縮約１,*
958 動詞,自立,*,*,五段動詞,仮定縮約１,1
959 動詞,自立,*,*,五段動詞,仮定縮約１,2
960 動詞,自立,*,*,五段動詞,仮定縮約１,3
961 動詞,自立,*,*,五段動詞,仮定縮約１,4
962 動詞,自立,*,*,五段動詞,仮定縮約１,5
963 動詞,自立,*,*,五段動詞,仮定縮約１,6
964 動詞,自立,*,*,五段動詞,仮定縮約１,7
965 動詞,自立,*,*,五段動詞,仮定縮約１,8
966 動詞,自立,*,*,五段動詞,体言接続特殊,*
967 動詞,自立,*,*,五段動詞,体言接続特殊,1
968 動詞,自立,*,*,五段動詞,体言接続特殊,2
969 動詞,自立,*,*,五段動詞,体言接続特殊,3
970 動詞,自立,*,*,五段動詞,体言接続特殊,4
971 動詞,自立,*,*,五段動詞,体言接続特殊,5
972 動詞,自立,*,*,五段動詞,体言接続特殊,6
973 動詞,自立,*,*,五段動詞,体言接続特殊,7
974 動詞,自立,*,*,五段動詞,体言接続特殊,8
975 動詞,自立,*,*,五段動詞,命令ｅ,*
976 動詞,自立,*,*,五段動詞,命令ｅ,1
977 動詞,自立,*,*,五段動詞,命令ｅ,2
978 動詞,自立,*,*,五段動詞,命令ｅ,3
979 動詞,自立,*,*,五段動詞,命令ｅ,4
980 動詞,自立,*,*,五段動詞,命令ｅ,5
981 動詞,自立,*,*,五段動詞,命令ｅ,6
982 動詞,自立,*,*,五段動詞,命令ｅ,7
983 動詞,自立,*,*,五段動詞,命令ｅ,8
984 動詞,自立,*,*,五段動詞,命令ｉ,3
985 動詞,自立,*,*,五段動詞,命令ｉ,5
986 動詞,自立,*,*,五段動詞,命令ｉ,6
987 動詞,自立,*,*,五段動詞,基本形,*
988 動詞,自立,*,*,五段動詞,基本形,1
989 動詞,自立,*,*,五段動詞,基本形,2
990 動詞,自立,*,*,五段動詞,基本形,3
991 動詞,自立,*,*,五段動詞,基本形,4
992 動詞,自立,*,*,五段動詞,基本形,5
993 動詞,自立,*,*,五段動詞,基本形,6
994 動詞,自立,*,*,五段動詞,基本形,7
995 動詞,自立,*,*,五段動詞,基本形,8
996 動詞,自立,*,*,五段動詞,未然ウ接続,*
997 動詞,自立,*,*,五段動詞,未然ウ接続,1
998 動詞,自立,*,*,五段動詞,未然ウ接続,2
999 動詞,自立,*,*,五段動詞,未然ウ接続,3
1000 動詞,自立,*,*,五段動詞,未然ウ接続,4
1001 動詞,自立,*,*,五段動詞,未然ウ接続,5
1002 動詞,自立,*,*,五段動詞,未然ウ接続,6
1003 動詞,自立,*,*,五段動詞,未然ウ接続,7
1004 動詞,自立,*,*,五段動詞,未然ウ接続,8
1005 動詞,自立,*,*,五段動詞,未然形,*
1006 動詞,自立,*,*,五段動詞,未然形,1
1007 動詞,自立,*,*,五段動詞,未然形,2
1008 動詞,自立,*,*,五段動詞,未然形,3
1009 動詞,自立,*,*,五段動詞,未然形,4
1010 動詞,自立,*,*,五段動詞,未然形,5
1011 動詞,自立,*,*,五段動詞,未然形,6
1012 動詞,自立,*,*,五段動詞,未然形,7
1013 動詞,自立,*,*,五段動詞,未然形,8
1014 動詞,自立,*,*,五段動詞,未然特殊,*
1015 動詞,自立,*,*,五段動詞,未然特殊,1
1016 動詞,自立,*,*,五段動詞,未然特殊,2
1017 動詞,自立,*,*,五段動詞,未然特殊,3
1018 動詞,自立,*,*,五段動詞,未然特殊,4
1019 動詞,自立,*,*,五段動詞,未然特殊,5
1020 動詞,自立,*,*,五段動詞,未然特殊,6
1021 動詞,自立,*,*,五段動詞,未然特殊,7
1022 動詞,自立,*,*,五段動詞,未然特殊,8
1023 動詞,自立,*,*,五段動詞,連用タ接続,*
1024 動詞,自立,*,*,五段動詞,連用タ接続,1
1025 動詞,自立,*,*,五段動詞,連用タ接続,2
1026 動詞,自立,*,*,五段動詞,連用タ接続,3
1027 動詞,自立,*,*,五段動詞,連用タ接続,4
1028 動詞,自立,*,*,五段動詞,連用タ接続,5
1029 動詞,自立,*,*,五段動詞,連用タ接続,6
1030 動詞,自立,*,*,五段動詞,連用タ接続,7
1031 動詞,自立,*,*,五段動詞,連用タ接続,8
1032 動詞,自立,*,*,五段動詞,連用形,*
1033 動詞,自立,*,*,五段動詞,連用形,1
1034 動詞,自立,*,*,五段動詞,連用形,2
1035 動詞,自立,*,*,五段動詞,連用形,3
1036 動詞,自立,*,*,五段動詞,連用形,4
1037 動詞,自立,*,*,五段動詞,連用形,5
1038 動詞,自立,*,*,五段動詞,連用形,6
1039 動詞,自立,*,*,五段動詞,連用形,7
1040 動詞,自立,*,*,五段動詞,連用形,8
1041 動詞,自立,*,*,四段・タ行,仮定形,*
1042 動詞,自立,*,*,四段・タ行,命令ｅ,*
1043 動詞,自立,*,*,四段・タ行,基本形,*
1044 動詞,自立,*,*,四段・タ行,未然形,*
1045 動詞,自立,*,*,四段・タ行,連用形,*
1046 動詞,自立,*,*,文語,丁寧連用形,3
1047 動詞,自立,*,*,文語,丁寧連用形,5
1048 動詞,自立,*,*,文語,丁寧連用形,8
1049 動詞,自立,*,*,文語,仮定形,*
1050 動詞,自立,*,*,文語,仮定形,2
1051 動詞,自立,*,*,文語,仮定形,3
1052 動詞,自立,*,*,文語,仮定形,5
1053 動詞,自立,*,*,文語,仮定形,8
1054 動詞,自立,*,*,文語,体言接続,2
1055 動詞,自立,*,*,文語,体言接続,3
1056 動詞,自立,*,*,文語,体言接続,5
1057 動詞,自立,*,*,文語,体言接続,8
1058 動詞,自立,*,*,文語,命令ｅ,*
1059 動詞,自立,*,*,文語,命令ｅ,3
1060 動詞,自立,*,*,文語,命令ｅ,5
1061 動詞,自立,*,*,文語,命令ｅ,8
1062 動詞,自立,*,*,文語,命令ｙｏ,2
1063 動詞,自立,*,*,文語,命令ｙｏ,3
1064 動詞,自立,*,*,文語,命令ｙｏ,5
1065 動詞,自立,*,*,文語,命令ｙｏ,8
1066 動詞,自立,*,*,文語,基本形,*
1067 動詞,自立,*,*,文語,基本形,2
1068 動詞,自立,*,*,文語,基本形,3
1069 動詞,自立,*,*,文語,基本形,5
1070 動詞,自立,*,*,文語,基本形,8
1071 動詞,自立,*,*,文語,未然ウ接続,2
1072 動詞,自立,*,*,文語,未然形,*
1073 動詞,自立,*,*,文語,未然形,2
1074 動詞,自立,*,*,文語,未然形,3
1075 動詞,自立,*,*,文語,未然形,5
1076 動詞,自立,*,*,文語,未然形,8
1077 動詞,自立,*,*,文語,現代基本形,5
1078 動詞,自立,*,*,文語,連用形,*
1079 動詞,自立,*,*,文語,連用形,2
1080 動詞,自立,*,*,文語,連用形,3
1081 動詞,自立,*,*,文語,連用形,5
1082 動詞,自立,*,*,文語,連用形,8
1083 動詞,非自立,*,*,カ変・クル,仮定形,くる
1084 動詞,非自立,*,*,カ変・クル,仮定縮約１,くる
1085 動詞,非自立,*,*,カ変・クル,体言接続特殊,くる
1086 動詞,非自立,*,*,カ変・クル,体言接続特殊２,くる
1087 動詞,非自立,*,*,カ変・クル,命令ｉ,くる
1088 動詞,非自立,*,*,カ変・クル,命令ｙｏ,くる
1089 動詞,非自立,*,*,カ変・クル,基本形,くる
1090 動詞,非自立,*,*,カ変・クル,未然ウ接続,くる
1091 動詞,非自立,*,*,カ変・クル,未然形,くる
1092 動詞,非自立,*,*,カ変・クル,連用形,くる
1093 動詞,非自立,*,*,カ変・来ル,仮定形,来る
1094 動詞,非自立,*,*,カ変・来ル,仮定縮約１,来る
1095 動詞,非自立,*,*,カ変・来ル,体言接続特殊,来る
1096 動詞,非自立,*,*,カ変・来ル,体言接続特殊２,来る
1097 動詞,非自立,*,*,カ変・来ル,命令ｉ,来る
1098 動詞,非自立,*,*,カ変・来ル,命令ｙｏ,来る
1099 動詞,非自立,*,*,カ変・来ル,基本形,来る
1100 動詞,非自立,*,*,カ変・来ル,未然ウ接続,来る
1101 動詞,非自立,*,*,カ変・来ル,未然形,来る
1102 動詞,非自立,*,*,カ変・来ル,連用形,来る
1103 動詞,非自立,*,*,一段,仮定形,あげる
1104 動詞,非自立,*,*,一段,仮定形,いける
1105 動詞,非自立,*,*,一段,仮定形,いる
1106 動詞,非自立,*,*,一段,仮定形,える
1107 動詞,非自立,*,*,一段,仮定形,かける
1108 動詞,非自立,*,*,一段,仮定形,かねる
1109 動詞,非自立,*,*,一段,仮定形,きれる
1110 動詞,非自立,*,*,一段,仮定形,すぎる
1111 動詞,非自立,*,*,一段,仮定形,そこねる
1112 動詞,非自立,*,*,一段,仮定形,そびれる
1113 動詞,非自立,*,*,一段,仮定形,たげる
1114 動詞,非自立,*,*,一段,仮定形,つける
1115 動詞,非自立,*,*,一段,仮定形,つづける
1116 動詞,非自立,*,*,一段,仮定形,づける
1117 動詞,非自立,*,*,一段,仮定形,てる
1118 動詞,非自立,*,*,一段,仮定形,できる
1119 動詞,非自立,*,*,一段,仮定形,でる
1120 動詞,非自立,*,*,一段,仮定形,のける
1121 動詞,非自立,*,*,一段,仮定形,はじめる
1122 動詞,非自立,*,*,一段,仮定形,みせる
1123 動詞,非自立,*,*,一段,仮定形,みる
1124 動詞,非自立,*,*,一段,仮定形,もらえる
1125 動詞,非自立,*,*,一段,仮定形,る
1126 動詞,非自立,*,*,一段,仮定形,上げる
1127 動詞,非自立,*,*,一段,仮定形,切れる
1128 動詞,非自立,*,*,一段,仮定形,始める
1129 動詞,非自立,*,*,一段,仮定形,得る
1130 動詞,非自立,*,*,一段,仮定形,終える
1131 動詞,非自立,*,*,一段,仮定形,続ける
1132 動詞,非自立,*,*,一段,仮定形,過ぎる
1133 動詞,非自立,*,*,一段,仮定形,願える
1134 動詞,非自立,*,*,一段,仮定縮約１,あげる
1135 動詞,非自立,*,*,一段,仮定縮約１,いける
1136 動詞,非自立,*,*,一段,仮定縮約１,いる
1137 動詞,非自立,*,*,一段,仮定縮約１,える
1138 動詞,非自立,*,*,一段,仮定縮約１,かける
1139 動詞,非自立,*,*,一段,仮定縮約１,かねる
1140 動詞,非自立,*,*,一段,仮定縮約１,きれる
1141 動詞,非自立,*,*,一段,仮定縮約１,すぎる
1142 動詞,非自立,*,*,一段,仮定縮約１,そこねる
1143 動詞,非自立,*,*,一段,仮定縮約１,そびれる
1144 動詞,非自立,*,*,一段,仮定縮約１,たげる
1145 動詞,非自立,*,*,一段,仮定縮約１,つける
1146 動詞,非自立,*,*,一段,仮定縮約１,つづける
1147 動詞,非自立,*,*,一段,仮定縮約１,づける
1148 動詞,非自立,*,*,一段,仮定縮約１,てる
1149 動詞,非自立,*,*,一段,仮定縮約１,できる
1150 動詞,非自立,*,*,一段,仮定縮約１,でる
1151 動詞,非自立,*,*,一段,仮定縮約１,のける
1152 動詞,非自立,*,*,一段,仮定縮約１,はじめる
1153 動詞,非自立,*,*,一段,仮定縮約１,みせる
1154 動詞,非自立,*,*,一段,仮定縮約１,みる
1155 動詞,非自立,*,*,一段,仮定縮約１,もらえる
1156 動詞,非自立,*,*,一段,仮定縮約１,る
1157 動詞,非自立,*,*,一段,仮定縮約１,上げる
1158 動詞,非自立,*,*,一段,仮定縮約１,切れる
1159 動詞,非自立,*,*,一段,仮定縮約１,始める
1160 動詞,非自立,*,*,一段,仮定縮約１,得る
1161 動詞,非自立,*,*,一段,仮定縮約１,終える
1162 動詞,非自立,*,*,一段,仮定縮約１,続ける
1163 動詞,非自立,*,*,一段,仮定縮約１,過ぎる
1164 動詞,非自立,*,*,一段,仮定縮約１,願える
1165 動詞,非自立,*,*,一段,体言接続特殊,あげる
1166 動詞,非自立,*,*,一段,体言接続特殊,いける
1167 動詞,非自立,*,*,一段,体言接続特殊,いる
1168 動詞,非自立,*,*,一段,体言接続特殊,える
1169 動詞,非自立,*,*,一段,体言接続特殊,かける
1170 動詞,非自立,*,*,一段,体言接続特殊,かねる
1171 動詞,非自立,*,*,一段,体言接続特殊,きれる
1172 動詞,非自立,*,*,一段,体言接続特殊,すぎる
1173 動詞,非自立,*,*,一段,体言接続特殊,そこねる
1174 動詞,非自立,*,*,一段,体言接続特殊,そびれる
1175 動詞,非自立,*,*,一段,体言接続特殊,たげる
1176 動詞,非自立,*,*,一段,体言接続特殊,つける
1177 動詞,非自立,*,*,一段,体言接続特殊,つづける
1178 動詞,非自立,*,*,一段,体言接続特殊,づける
1179 動詞,非自立,*,*,一段,体言接続特殊,てる
1180 動詞,非自立,*,*,一段,体言接続特殊,できる
1181 動詞,非自立,*,*,一段,体言接続特殊,でる
1182 動詞,非自立,*,*,一段,体言接続特殊,のける
1183 動詞,非自立,*,*,一段,体言接続特殊,はじめる
1184 動詞,非自立,*,*,一段,体言接続特殊,みせる
1185 動詞,非自立,*,*,一段,体言接続特殊,みる
1186 動詞,非自立,*,*,一段,体言接続特殊,もらえる
1187 動詞,非自立,*,*,一段,体言接続特殊,る
1188 動詞,非自立,*,*,一段,体言接続特殊,上げる
1189 動詞,非自立,*,*,一段,体言接続特殊,切れる
1190 動詞,非自立,*,*,一段,体言接続特殊,始める
1191 動詞,非自立,*,*,一段,体言接続特殊,得る
1192 動詞,非自立,*,*,一段,体言接続特殊,終える
1193 動詞,非自立,*,*,一段,体言接続特殊,続ける
1194 動詞,非自立,*,*,一段,体言接続特殊,過ぎる
1195 動詞,非自立,*,*,一段,体言接続特殊,願える
1196 動詞,非自立,*,*,一段,命令ｒｏ,あげる
1197 動詞,非自立,*,*,一段,命令ｒｏ,いける
1198 動詞,非自立,*,*,一段,命令ｒｏ,いる
1199 動詞,非自立,*,*,一段,命令ｒｏ,える
1200 動詞,非自立,*,*,一段,命令ｒｏ,かける
1201 動詞,非自立,*,*,一段,命令ｒｏ,かねる
1202 動詞,非自立,*,*,一段,命令ｒｏ,きれる
1203 動詞,非自立,*,*,一段,命令ｒｏ,すぎる
1204 動詞,非自立,*,*,一段,命令ｒｏ,そこねる
1205 動詞,非自立,*,*,一段,命令ｒｏ,そびれる
1206 動詞,非自立,*,*,一段,命令ｒｏ,たげる
1207 動詞,非自立,*,*,一段,命令ｒｏ,つける
1208 動詞,非自立,*,*,一段,命令ｒｏ,つづける
1209 動詞,非自立,*,*,一段,命令ｒｏ,づける
1210 動詞,非自立,*,*,一段,命令ｒｏ,てる
1211 動詞,非自立,*,*,一段,命令ｒｏ,できる
1212 動詞,非自立,*,*,一段,命令ｒｏ,でる
1213 動詞,非自立,*,*,一段,命令ｒｏ,のける
1214 動詞,非自立,*,*,一段,命令ｒｏ,はじめる
1215 動詞,非自立,*,*,一段,命令ｒｏ,みせる
1216 動詞,非自立,*,*,一段,命令ｒｏ,みる
1217 動詞,非自立,*,*,一段,命令ｒｏ,もらえる
1218 動詞,非自立,*,*,一段,命令ｒｏ,る
1219 動詞,非自立,*,*,一段,命令ｒｏ,上げる
1220 動詞,非自立,*,*,一段,命令ｒｏ,切れる
1221 動詞,非自立,*,*,一段,命令ｒｏ,始める
1222 動詞,非自立,*,*,一段,命令ｒｏ,得る
1223 動詞,非自立,*,*,一段,命令ｒｏ,終える
1224 動詞,非自立,*,*,一段,命令ｒｏ,続ける
1225 動詞,非自立,*,*,一段,命令ｒｏ,過ぎる
1226 動詞,非自立,*,*,一段,命令ｒｏ,願える
1227 動詞,非自立,*,*,一段,命令ｙｏ,あげる
1228 動詞,非自立,*,*,一段,命令ｙｏ,いける
1229 動詞,非自立,*,*,一段,命令ｙｏ,いる
1230 動詞,非自立,*,*,一段,命令ｙｏ,える
1231 動詞,非自立,*,*,一段,命令ｙｏ,かける
1232 動詞,非自立,*,*,一段,命令ｙｏ,かねる
1233 動詞,非自立,*,*,一段,命令ｙｏ,きれる
1234 動詞,非自立,*,*,一段,命令ｙｏ,すぎる
1235 動詞,非自立,*,*,一段,命令ｙｏ,そこねる
1236 動詞,非自立,*,*,一段,命令ｙｏ,そびれる
1237 動詞,非自立,*,*,一段,命令ｙｏ,たげる
1238 動詞,非自立,*,*,一段,命令ｙｏ,つける
1239 動詞,非自立,*,*,一段,命令ｙｏ,つづける
1240 動詞,非自立,*,*,一段,命令ｙｏ,づける
1241 動詞,非自立,*,*,一段,命令ｙｏ,てる
1242 動詞,非自立,*,*,一段,命令ｙｏ,できる
1243 動詞,非自立,*,*,一段,命令ｙｏ,でる
1244 動詞,非自立,*,*,一段,命令ｙｏ,のける
1245 動詞,非自立,*,*,一段,命令ｙｏ,はじめる
1246 動詞,非自立,*,*,一段,命令ｙｏ,みせる
1247 動詞,非自立,*,*,一段,命令ｙｏ,みる
1248 動詞,非自立,*,*,一段,命令ｙｏ,もらえる
1249 動詞,非自立,*,*,一段,命令ｙｏ,る
1250 動詞,非自立,*,*,一段,命令ｙｏ,上げる
1251 動詞,非自立,*,*,一段,命令ｙｏ,切れる
1252 動詞,非自立,*,*,一段,命令ｙｏ,始める
1253 動詞,非自立,*,*,一段,命令ｙｏ,得る
1254 動詞,非自立,*,*,一段,命令ｙｏ,終える
1255 動詞,非自立,*,*,一段,命令ｙｏ,続ける
1256 動詞,非自立,*,*,一段,命令ｙｏ,過ぎる
1257 動詞,非自立,*,*,一段,命令ｙｏ,願える
1258 動詞,非自立,*,*,一段,基本形,あげる
1259 動詞,非自立,*,*,一段,基本形,いける
1260 動詞,非自立,*,*,一段,基本形,いる
1261 動詞,非自立,*,*,一段,基本形,える
1262 動詞,非自立,*,*,一段,基本形,かける
1263 動詞,非自立,*,*,一段,基本形,かねる
1264 動詞,非自立,*,*,一段,基本形,きれる
1265 動詞,非自立,*,*,一段,基本形,すぎる
1266 動詞,非自立,*,*,一段,基本形,そこねる
1267 動詞,非自立,*,*,一段,基本形,そびれる
1268 動詞,非自立,*,*,一段,基本形,たげる
1269 動詞,非自立,*,*,一段,基本形,つける
1270 動詞,非自立,*,*,一段,基本形,つづける
1271 動詞,非自立,*,*,一段,基本形,づける
1272 動詞,非自立,*,*,一段,基本形,てる
1273 動詞,非自立,*,*,一段,基本形,できる
1274 動詞,非自立,*,*,一段,基本形,でる
1275 動詞,非自立,*,*,一段,基本形,のける
1276 動詞,非自立,*,*,一段,基本形,はじめる
1277 動詞,非自立,*,*,一段,基本形,みせる
1278 動詞,非自立,*,*,一段,基本形,みる
1279 動詞,非自立,*,*,一段,基本形,もらえる
1280 動詞,非自立,*,*,一段,基本形,る
1281 動詞,非自立,*,*,一段,基本形,上げる
1282 動詞,非自立,*,*,一段,基本形,切れる
1283 動詞,非自立,*,*,一段,基本形,始める
1284 動詞,非自立,*,*,一段,基本形,得る
1285 動詞,非自立,*,*,一段,基本形,終える
1286 動詞,非自立,*,*,一段,基本形,続ける
1287 動詞,非自立,*,*,一段,基本形,過ぎる
1288 動詞,非自立,*,*,一段,基本形,願える
1289 動詞,非自立,*,*,一段,未然ウ接続,あげる
1290 動詞,非自立,*,*,一段,未然ウ接続,いける
1291 動詞,非自立,*,*,一段,未然ウ接続,いる
1292 動詞,非自立,*,*,一段,未然ウ接続,える
1293 動詞,非自立,*,*,一段,未然ウ接続,かける
1294 動詞,非自立,*,*,一段,未然ウ接続,かねる
1295 動詞,非自立,*,*,一段,未然ウ接続,きれる
1296 動詞,非自立,*,*,一段,未然ウ接続,すぎる
1297 動詞,非自立,*,*,一段,未然ウ接続,そこねる
1298 動詞,非自立,*,*,一段,未然ウ接続,そびれる
1299 動詞,非自立,*,*,一段,未然ウ接続,たげる
1300 動詞,非自立,*,*,一段,未然ウ接続,つける
1301 動詞,非自立,*,*,一段,未然ウ接続,つづける
1302 動詞,非自立,*,*,一段,未然ウ接続,づける
1303 動詞,非自立,*,*,一段,未然ウ接続,てる
1304 動詞,非自立,*,*,一段,未然ウ接続,できる
1305 動詞,非自立,*,*,一段,未然ウ接続,でる
1306 動詞,非自立,*,*,一段,未然ウ接続,のける
1307 動詞,非自立,*,*,一段,未然ウ接続,はじめる
1308 動詞,非自立,*,*,一段,未然ウ接続,みせる
1309 動詞,非自立,*,*,一段,未然ウ接続,みる
1310 動詞,非自立,*,*,一段,未然ウ接続,もらえる
1311 動詞,非自立,*,*,一段,未然ウ接続,る
1312 動詞,非自立,*,*,一段,未然ウ接続,上げる
1313 動詞,非自立,*,*,一段,未然ウ接続,切れる
1314 動詞,非自立,*,*,一段,未然ウ接続,始める
1315 動詞,非自立,*,*,一段,未然ウ接続,得る
1316 動詞,非自立,*,*,一段,未然ウ接続,終える
1317 動詞,非自立,*,*,一段,未然ウ接続,続ける
1318 動詞,非自立,*,*,一段,未然ウ接続,過ぎる
1319 動詞,非自立,*,*,一段,未然ウ接続,願える
1320 動詞,非自立,*,*,一段,未然形,あげる
1321 動詞,非自立,*,*,一段,未然形,いける
1322 動詞,非自立,*,*,一段,未然形,いる
1323 動詞,非自立,*,*,一段,未然形,える
1324 動詞,非自立,*,*,一段,未然形,かける
1325 動詞,非自立,*,*,一段,未然形,かねる
1326 動詞,非自立,*,*,一段,未然形,きれる
1327 動詞,非自立,*,*,一段,未然形,すぎる
1328 動詞,非自立,*,*,一段,未然形,そこねる
1329 動詞,非自立,*,*,一段,未然形,そびれる
1330 動詞,非自立,*,*,一段,未然形,たげる
1331 動詞,非自立,*,*,一段,未然形,つける
1332 動詞,非自立,*,*,一段,未然形,つづける
1333 動詞,非自立,*,*,一段,未然形,づける
1334 動詞,非自立,*,*,一段,未然形,てる
1335 動詞,非自立,*,*,一段,未然形,できる
1336 動詞,非自立,*,*,一段,未然形,でる
1337 動詞,非自立,*,*,一段,未然形,のける
1338 動詞,非自立,*,*,一段,未然形,はじめる
1339 動詞,非自立,*,*,一段,未然形,みせる
1340 動詞,非自立,*,*,一段,未然形,みる
1341 動詞,非自立,*,*,一段,未然形,もらえる
1342 動詞,非自立,*,*,一段,未然形,上げる
1343 動詞,非自立,*,*,一段,未然形,切れる
1344 動詞,非自立,*,*,一段,未然形,始める
1345 動詞,非自立,*,*,一段,未然形,得る
1346 動詞,非自立,*,*,一段,未然形,終える
1347 動詞,非自立,*,*,一段,未然形,続ける
1348 動詞,非自立,*,*,一段,未然形,過ぎる
1349 動詞,非自立,*,*,一段,未然形,願える
1350 動詞,非自立,*,*,一段,連用形,あげる
1351 動詞,非自立,*,*,一段,連用形,いける
1352 動詞,非自立,*,*,一段,連用形,いる
1353 動詞,非自立,*,*,一段,連用形,える
1354 動詞,非自立,*,*,一段,連用形,かける
1355 動詞,非自立,*,*,一段,連用形,かねる
1356 動詞,非自立,*,*,一段,連用形,きれる
1357 動詞,非自立,*,*,一段,連用形,すぎる
1358 動詞,非自立,*,*,一段,連用形,そこねる
1359 動詞,非自立,*,*,一段,連用形,そびれる
1360 動詞,非自立,*,*,一段,連用形,たげる
1361 動詞,非自立,*,*,一段,連用形,つける
1362 動詞,非自立,*,*,一段,連用形,つづける
1363 動詞,非自立,*,*,一段,連用形,づける
1364 動詞,非自立,*,*,一段,連用形,てる
1365 動詞,非自立,*,*,一段,連用形,できる
1366 動詞,非自立,*,*,一段,連用形,でる
1367 動詞,非自立,*,*,一段,連用形,のける
1368 動詞,非自立,*,*,一段,連用形,はじめる
1369 動詞,非自立,*,*,一段,連用形,みせる
1370 動詞,非自立,*,*,一段,連用形,みる
1371 動詞,非自立,*,*,一段,連用形,もらえる
1372 動詞,非自立,*,*,一段,連用形,上げる
1373 動詞,非自立,*,*,一段,連用形,切れる
1374 動詞,非自立,*,*,一段,連用形,始める
1375 動詞,非自立,*,*,一段,連用形,得る
1376 動詞,非自立,*,*,一段,連用形,終える
1377 動詞,非自立,*,*,一段,連用形,続ける
1378 動詞,非自立,*,*,一段,連用形,過ぎる
1379 動詞,非自立,*,*,一段,連用形,願える
1380 動詞,非自立,*,*,一段・クレル,仮定形,くれる
1381 動詞,非自立,*,*,一段・クレル,仮定縮約１,くれる
1382 動詞,非自立,*,*,一段・クレル,命令ｅ,くれる
1383 動詞,非自立,*,*,一段・クレル,命令ｒｏ,くれる
1384 動詞,非自立,*,*,一段・クレル,命令ｙｏ,くれる
1385 動詞,非自立,*,*,一段・クレル,基本形,くれる
1386 動詞,非自立,*,*,一段・クレル,未然ウ接続,くれる
1387 動詞,非自立,*,*,一段・クレル,未然形,くれる
1388 動詞,非自立,*,*,一段・クレル,未然特殊,くれる
1389 動詞,非自立,*,*,一段・クレル,連用形,くれる
1390 動詞,非自立,*,*,一段・得ル,仮定形,うる
1391 動詞,非自立,*,*,一段・得ル,仮定形,得る
1392 動詞,非自立,*,*,一段・得ル,基本形,うる
1393 動詞,非自立,*,*,一段・得ル,基本形,得る
1394 動詞,非自立,*,*,五段・カ行イ音便,仮定形,いただく
1395 動詞,非自立,*,*,五段・カ行イ音便,仮定形,おく
1396 動詞,非自立,*,*,五段・カ行イ音便,仮定形,とく
1397 動詞,非自立,*,*,五段・カ行イ音便,仮定形,どく
1398 動詞,非自立,*,*,五段・カ行イ音便,仮定形,ぬく
1399 動詞,非自立,*,*,五段・カ行イ音便,仮定形,めく
1400 動詞,非自立,*,*,五段・カ行イ音便,仮定形,抜く
1401 動詞,非自立,*,*,五段・カ行イ音便,仮定形,続く
1402 動詞,非自立,*,*,五段・カ行イ音便,仮定形,頂く
1403 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,いただく
1404 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,おく
1405 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,とく
1406 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,どく
1407 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,ぬく
1408 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,めく
1409 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,抜く
1410 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,続く
1411 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,頂く
1412 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,いただく
1413 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,おく
1414 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,とく
1415 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,どく
1416 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,ぬく
1417 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,めく
1418 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,抜く
1419 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,続く
1420 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,頂く
1421 動詞,非自立,*,*,五段・カ行イ音便,基本形,いただく
1422 動詞,非自立,*,*,五段・カ行イ音便,基本形,おく
1423 動詞,非自立,*,*,五段・カ行イ音便,基本形,とく
1424 動詞,非自立,*,*,五段・カ行イ音便,基本形,どく
1425 動詞,非自立,*,*,五段・カ行イ音便,基本形,ぬく
1426 動詞,非自立,*,*,五段・カ行イ音便,基本形,めく
1427 動詞,非自立,*,*,五段・カ行イ音便,基本形,抜く
1428 動詞,非自立,*,*,五段・カ行イ音便,基本形,続く
1429 動詞,非自立,*,*,五段・カ行イ音便,基本形,頂く
1430 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,いただく
1431 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,おく
1432 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,とく
1433 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,どく
1434 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,ぬく
1435 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,めく
1436 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,抜く
1437 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,続く
1438 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,頂く
1439 動詞,非自立,*,*,五段・カ行イ音便,未然形,いただく
1440 動詞,非自立,*,*,五段・カ行イ音便,未然形,おく
1441 動詞,非自立,*,*,五段・カ行イ音便,未然形,とく
1442 動詞,非自立,*,*,五段・カ行イ音便,未然形,どく
1443 動詞,非自立,*,*,五段・カ行イ音便,未然形,ぬく
1444 動詞,非自立,*,*,五段・カ行イ音便,未然形,めく
1445 動詞,非自立,*,*,五段・カ行イ音便,未然形,抜く
1446 動詞,非自立,*,*,五段・カ行イ音便,未然形,続く
1447 動詞,非自立,*,*,五段・カ行イ音便,未然形,頂く
1448 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,いただく
1449 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,おく
1450 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,とく
1451 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,どく
1452 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,ぬく
1453 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,めく
1454 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,抜く
1455 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,続く
1456 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,頂く
1457 動詞,非自立,*,*,五段・カ行イ音便,連用形,いただく
1458 動詞,非自立,*,*,五段・カ行イ音便,連用形,おく
1459 動詞,非自立,*,*,五段・カ行イ音便,連用形,とく
1460 動詞,非自立,*,*,五段・カ行イ音便,連用形,どく
1461 動詞,非自立,*,*,五段・カ行イ音便,連用形,ぬく
1462 動詞,非自立,*,*,五段・カ行イ音便,連用形,めく
1463 動詞,非自立,*,*,五段・カ行イ音便,連用形,抜く
1464 動詞,非自立,*,*,五段・カ行イ音便,連用形,続く
1465 動詞,非自立,*,*,五段・カ行イ音便,連用形,頂く
1466 動詞,非自立,*,*,五段・カ行促音便,仮定形,いく
1467 動詞,非自立,*,*,五段・カ行促音便,仮定形,く
1468 動詞,非自立,*,*,五段・カ行促音便,仮定形,てく
1469 動詞,非自立,*,*,五段・カ行促音便,仮定形,でく
1470 動詞,非自立,*,*,五段・カ行促音便,仮定形,行く
1471 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,いく
1472 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,く
1473 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,てく
1474 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,でく
1475 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,ク
1476 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,行く
1477 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,いく
1478 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,く
1479 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,てく
1480 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,でく
1481 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,行く
1482 動詞,非自立,*,*,五段・カ行促音便,基本形,いく
1483 動詞,非自立,*,*,五段・カ行促音便,基本形,く
1484 動詞,非自立,*,*,五段・カ行促音便,基本形,てく
1485 動詞,非自立,*,*,五段・カ行促音便,基本形,でく
1486 動詞,非自立,*,*,五段・カ行促音便,基本形,行く
1487 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,いく
1488 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,く
1489 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,てく
1490 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,でく
1491 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,行く
1492 動詞,非自立,*,*,五段・カ行促音便,未然形,いく
1493 動詞,非自立,*,*,五段・カ行促音便,未然形,く
1494 動詞,非自立,*,*,五段・カ行促音便,未然形,てく
1495 動詞,非自立,*,*,五段・カ行促音便,未然形,でく
1496 動詞,非自立,*,*,五段・カ行促音便,未然形,行く
1497 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,いく
1498 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,く
1499 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,てく
1500 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,でく
1501 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,行く
1502 動詞,非自立,*,*,五段・カ行促音便,連用形,いく
1503 動詞,非自立,*,*,五段・カ行促音便,連用形,く
1504 動詞,非自立,*,*,五段・カ行促音便,連用形,てく
1505 動詞,非自立,*,*,五段・カ行促音便,連用形,でく
1506 動詞,非自立,*,*,五段・カ行促音便,連用形,行く
1507 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,ゆく
1508 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,行く
1509 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,ゆく
1510 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,行く
1511 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,ゆく
1512 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,行く
1513 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,ゆく
1514 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,行く
1515 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,ゆく
1516 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,行く
1517 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,ゆく
1518 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,行く
1519 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,ゆく
1520 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,行く
1521 動詞,非自立,*,*,五段・サ行,仮定形,いたす
1522 動詞,非自立,*,*,五段・サ行,仮定形,だす
1523 動詞,非自立,*,*,五段・サ行,仮定形,つくす
1524 動詞,非自立,*,*,五段・サ行,仮定形,なおす
1525 動詞,非自立,*,*,五段・サ行,仮定形,出す
1526 動詞,非自立,*,*,五段・サ行,仮定形,尽くす
1527 動詞,非自立,*,*,五段・サ行,仮定形,直す
1528 動詞,非自立,*,*,五段・サ行,仮定形,致す
1529 動詞,非自立,*,*,五段・サ行,仮定縮約１,いたす
1530 動詞,非自立,*,*,五段・サ行,仮定縮約１,だす
1531 動詞,非自立,*,*,五段・サ行,仮定縮約１,つくす
1532 動詞,非自立,*,*,五段・サ行,仮定縮約１,なおす
1533 動詞,非自立,*,*,五段・サ行,仮定縮約１,出す
1534 動詞,非自立,*,*,五段・サ行,仮定縮約１,尽くす
1535 動詞,非自立,*,*,五段・サ行,仮定縮約１,直す
1536 動詞,非自立,*,*,五段・サ行,仮定縮約１,致す
1537 動詞,非自立,*,*,五段・サ行,命令ｅ,いたす
1538 動詞,非自立,*,*,五段・サ行,命令ｅ,だす
1539 動詞,非自立,*,*,五段・サ行,命令ｅ,つくす
1540 動詞,非自立,*,*,五段・サ行,命令ｅ,なおす
1541 動詞,非自立,*,*,五段・サ行,命令ｅ,出す
1542 動詞,非自立,*,*,五段・サ行,命令ｅ,尽くす
1543 動詞,非自立,*,*,五段・サ行,命令ｅ,直す
1544 動詞,非自立,*,*,五段・サ行,命令ｅ,致す
1545 動詞,非自立,*,*,五段・サ行,基本形,いたす
1546 動詞,非自立,*,*,五段・サ行,基本形,だす
1547 動詞,非自立,*,*,五段・サ行,基本形,つくす
1548 動詞,非自立,*,*,五段・サ行,基本形,なおす
1549 動詞,非自立,*,*,五段・サ行,基本形,出す
1550 動詞,非自立,*,*,五段・サ行,基本形,尽くす
1551 動詞,非自立,*,*,五段・サ行,基本形,直す
1552 動詞,非自立,*,*,五段・サ行,基本形,致す
1553 動詞,非自立,*,*,五段・サ行,未然ウ接続,いたす
1554 動詞,非自立,*,*,五段・サ行,未然ウ接続,だす
1555 動詞,非自立,*,*,五段・サ行,未然ウ接続,つくす
1556 動詞,非自立,*,*,五段・サ行,未然ウ接続,なおす
1557 動詞,非自立,*,*,五段・サ行,未然ウ接続,出す
1558 動詞,非自立,*,*,五段・サ行,未然ウ接続,尽くす
1559 動詞,非自立,*,*,五段・サ行,未然ウ接続,直す
1560 動詞,非自立,*,*,五段・サ行,未然ウ接続,致す
1561 動詞,非自立,*,*,五段・サ行,未然形,いたす
1562 動詞,非自立,*,*,五段・サ行,未然形,だす
1563 動詞,非自立,*,*,五段・サ行,未然形,つくす
1564 動詞,非自立,*,*,五段・サ行,未然形,なおす
1565 動詞,非自立,*,*,五段・サ行,未然形,出す
1566 動詞,非自立,*,*,五段・サ行,未然形,尽くす
1567 動詞,非自立,*,*,五段・サ行,未然形,直す
1568 動詞,非自立,*,*,五段・サ行,未然形,致す
1569 動詞,非自立,*,*,五段・サ行,連用形,いたす
1570 動詞,非自立,*,*,五段・サ行,連用形,だす
1571 動詞,非自立,*,*,五段・サ行,連用形,つくす
1572 動詞,非自立,*,*,五段・サ行,連用形,なおす
1573 動詞,非自立,*,*,五段・サ行,連用形,出す
1574 動詞,非自立,*,*,五段・サ行,連用形,尽くす
1575 動詞,非自立,*,*,五段・サ行,連用形,直す
1576 動詞,非自立,*,*,五段・サ行,連用形,致す
1577 動詞,非自立,*,*,五段・マ行,仮定形,こむ
1578 動詞,非自立,*,*,五段・マ行,仮定形,込む
1579 動詞,非自立,*,*,五段・マ行,仮定縮約１,こむ
1580 動詞,非自立,*,*,五段・マ行,仮定縮約１,込む
1581 動詞,非自立,*,*,五段・マ行,命令ｅ,こむ
1582 動詞,非自立,*,*,五段・マ行,命令ｅ,込む
1583 動詞,非自立,*,*,五段・マ行,基本形,こむ
1584 動詞,非自立,*,*,五段・マ行,基本形,込む
1585 動詞,非自立,*,*,五段・マ行,未然ウ接続,こむ
1586 動詞,非自立,*,*,五段・マ行,未然ウ接続,込む
1587 動詞,非自立,*,*,五段・マ行,未然形,こむ
1588 動詞,非自立,*,*,五段・マ行,未然形,込む
1589 動詞,非自立,*,*,五段・マ行,連用タ接続,こむ
1590 動詞,非自立,*,*,五段・マ行,連用タ接続,込む
1591 動詞,非自立,*,*,五段・マ行,連用形,こむ
1592 動詞,非自立,*,*,五段・マ行,連用形,込む
1593 動詞,非自立,*,*,五段・ラ行,仮定形,ある
1594 動詞,非自立,*,*,五段・ラ行,仮定形,おる
1595 動詞,非自立,*,*,五段・ラ行,仮定形,かかる
1596 動詞,非自立,*,*,五段・ラ行,仮定形,きる
1597 動詞,非自立,*,*,五段・ラ行,仮定形,たる
1598 動詞,非自立,*,*,五段・ラ行,仮定形,とる
1599 動詞,非自立,*,*,五段・ラ行,仮定形,どる
1600 動詞,非自立,*,*,五段・ラ行,仮定形,なる
1601 動詞,非自立,*,*,五段・ラ行,仮定形,はる
1602 動詞,非自立,*,*,五段・ラ行,仮定形,まいる
1603 動詞,非自立,*,*,五段・ラ行,仮定形,まくる
1604 動詞,非自立,*,*,五段・ラ行,仮定形,まわる
1605 動詞,非自立,*,*,五段・ラ行,仮定形,やがる
1606 動詞,非自立,*,*,五段・ラ行,仮定形,やる
1607 動詞,非自立,*,*,五段・ラ行,仮定形,切る
1608 動詞,非自立,*,*,五段・ラ行,仮定形,参る
1609 動詞,非自立,*,*,五段・ラ行,仮定形,回る
1610 動詞,非自立,*,*,五段・ラ行,仮定形,終わる
1611 動詞,非自立,*,*,五段・ラ行,仮定縮約１,ある
1612 動詞,非自立,*,*,五段・ラ行,仮定縮約１,おる
1613 動詞,非自立,*,*,五段・ラ行,仮定縮約１,かかる
1614 動詞,非自立,*,*,五段・ラ行,仮定縮約１,きる
1615 動詞,非自立,*,*,五段・ラ行,仮定縮約１,たる
1616 動詞,非自立,*,*,五段・ラ行,仮定縮約１,とる
1617 動詞,非自立,*,*,五段・ラ行,仮定縮約１,どる
1618 動詞,非自立,*,*,五段・ラ行,仮定縮約１,なる
1619 動詞,非自立,*,*,五段・ラ行,仮定縮約１,はる
1620 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まいる
1621 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まくる
1622 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まわる
1623 動詞,非自立,*,*,五段・ラ行,仮定縮約１,やがる
1624 動詞,非自立,*,*,五段・ラ行,仮定縮約１,やる
1625 動詞,非自立,*,*,五段・ラ行,仮定縮約１,ドル
1626 動詞,非自立,*,*,五段・ラ行,仮定縮約１,切る
1627 動詞,非自立,*,*,五段・ラ行,仮定縮約１,参る
1628 動詞,非自立,*,*,五段・ラ行,仮定縮約１,回る
1629 動詞,非自立,*,*,五段・ラ行,仮定縮約１,終わる
1630 動詞,非自立,*,*,五段・ラ行,体言接続特殊,ある
1631 動詞,非自立,*,*,五段・ラ行,体言接続特殊,おる
1632 動詞,非自立,*,*,五段・ラ行,体言接続特殊,かかる
1633 動詞,非自立,*,*,五段・ラ行,体言接続特殊,きる
1634 動詞,非自立,*,*,五段・ラ行,体言接続特殊,たる
1635 動詞,非自立,*,*,五段・ラ行,体言接続特殊,とる
1636 動詞,非自立,*,*,五段・ラ行,体言接続特殊,どる
1637 動詞,非自立,*,*,五段・ラ行,体言接続特殊,なる
1638 動詞,非自立,*,*,五段・ラ行,体言接続特殊,はる
1639 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まいる
1640 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まくる
1641 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まわる
1642 動詞,非自立,*,*,五段・ラ行,体言接続特殊,やがる
1643 動詞,非自立,*,*,五段・ラ行,体言接続特殊,やる
1644 動詞,非自立,*,*,五段・ラ行,体言接続特殊,切る
1645 動詞,非自立,*,*,五段・ラ行,体言接続特殊,参る
1646 動詞,非自立,*,*,五段・ラ行,体言接続特殊,回る
1647 動詞,非自立,*,*,五段・ラ行,体言接続特殊,終わる
1648 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,ある
1649 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,おる
1650 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,かかる
1651 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,きる
1652 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,たる
1653 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,とる
1654 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,どる
1655 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,なる
1656 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,はる
1657 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まいる
1658 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まくる
1659 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まわる
1660 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,やる
1661 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,切る
1662 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,参る
1663 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,回る
1664 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,終わる
1665 動詞,非自立,*,*,五段・ラ行,命令ｅ,ある
1666 動詞,非自立,*,*,五段・ラ行,命令ｅ,おる
1667 動詞,非自立,*,*,五段・ラ行,命令ｅ,かかる
1668 動詞,非自立,*,*,五段・ラ行,命令ｅ,きる
1669 動詞,非自立,*,*,五段・ラ行,命令ｅ,たる
1670 動詞,非自立,*,*,五段・ラ行,命令ｅ,とる
1671 動詞,非自立,*,*,五段・ラ行,命令ｅ,どる
1672 動詞,非自立,*,*,五段・ラ行,命令ｅ,なる
1673 動詞,非自立,*,*,五段・ラ行,命令ｅ,はる
1674 動詞,非自立,*,*,五段・ラ行,命令ｅ,まいる
1675 動詞,非自立,*,*,五段・ラ行,命令ｅ,まくる
1676 動詞,非自立,*,*,五段・ラ行,命令ｅ,まわる
1677 動詞,非自立,*,*,五段・ラ行,命令ｅ,やがる
1678 動詞,非自立,*,*,五段・ラ行,命令ｅ,やる
1679 動詞,非自立,*,*,五段・ラ行,命令ｅ,切る
1680 動詞,非自立,*,*,五段・ラ行,命令ｅ,参る
1681 動詞,非自立,*,*,五段・ラ行,命令ｅ,回る
1682 動詞,非自立,*,*,五段・ラ行,命令ｅ,終わる
1683 動詞,非自立,*,*,五段・ラ行,基本形,ある
1684 動詞,非自立,*,*,五段・ラ行,基本形,おる
1685 動詞,非自立,*,*,五段・ラ行,基本形,かかる
1686 動詞,非自立,*,*,五段・ラ行,基本形,きる
1687 動詞,非自立,*,*,五段・ラ行,基本形,たる
1688 動詞,非自立,*,*,五段・ラ行,基本形,とる
1689 動詞,非自立,*,*,五段・ラ行,基本形,どる
1690 動詞,非自立,*,*,五段・ラ行,基本形,なる
1691 動詞,非自立,*,*,五段・ラ行,基本形,はる
1692 動詞,非自立,*,*,五段・ラ行,基本形,まいる
1693 動詞,非自立,*,*,五段・ラ行,基本形,まくる
1694 動詞,非自立,*,*,五段・ラ行,基本形,まわる
1695 動詞,非自立,*,*,五段・ラ行,基本形,やがる
1696 動詞,非自立,*,*,五段・ラ行,基本形,やる
1697 動詞,非自立,*,*,五段・ラ行,基本形,切る
1698 動詞,非自立,*,*,五段・ラ行,基本形,参る
1699 動詞,非自立,*,*,五段・ラ行,基本形,回る
1700 動詞,非自立,*,*,五段・ラ行,基本形,終わる
1701 動詞,非自立,*,*,五段・ラ行,未然ウ接続,ある
1702 動詞,非自立,*,*,五段・ラ行,未然ウ接続,おる
1703 動詞,非自立,*,*,五段・ラ行,未然ウ接続,かかる
1704 動詞,非自立,*,*,五段・ラ行,未然ウ接続,きる
1705 動詞,非自立,*,*,五段・ラ行,未然ウ接続,たる
1706 動詞,非自立,*,*,五段・ラ行,未然ウ接続,とる
1707 動詞,非自立,*,*,五段・ラ行,未然ウ接続,どる
1708 動詞,非自立,*,*,五段・ラ行,未然ウ接続,なる
1709 動詞,非自立,*,*,五段・ラ行,未然ウ接続,はる
1710 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まいる
1711 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まくる
1712 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まわる
1713 動詞,非自立,*,*,五段・ラ行,未然ウ接続,やがる
1714 動詞,非自立,*,*,五段・ラ行,未然ウ接続,やる
1715 動詞,非自立,*,*,五段・ラ行,未然ウ接続,切る
1716 動詞,非自立,*,*,五段・ラ行,未然ウ接続,参る
1717 動詞,非自立,*,*,五段・ラ行,未然ウ接続,回る
1718 動詞,非自立,*,*,五段・ラ行,未然ウ接続,終わる
1719 動詞,非自立,*,*,五段・ラ行,未然形,ある
1720 動詞,非自立,*,*,五段・ラ行,未然形,おる
1721 動詞,非自立,*,*,五段・ラ行,未然形,かかる
1722 動詞,非自立,*,*,五段・ラ行,未然形,きる
1723 動詞,非自立,*,*,五段・ラ行,未然形,たる
1724 動詞,非自立,*,*,五段・ラ行,未然形,とる
1725 動詞,非自立,*,*,五段・ラ行,未然形,どる
1726 動詞,非自立,*,*,五段・ラ行,未然形,なる
1727 動詞,非自立,*,*,五段・ラ行,未然形,はる
1728 動詞,非自立,*,*,五段・ラ行,未然形,まいる
1729 動詞,非自立,*,*,五段・ラ行,未然形,まくる
1730 動詞,非自立,*,*,五段・ラ行,未然形,まわる
1731 動詞,非自立,*,*,五段・ラ行,未然形,やがる
1732 動詞,非自立,*,*,五段・ラ行,未然形,やる
1733 動詞,非自立,*,*,五段・ラ行,未然形,切る
1734 動詞,非自立,*,*,五段・ラ行,未然形,参る
1735 動詞,非自立,*,*,五段・ラ行,未然形,回る
1736 動詞,非自立,*,*,五段・ラ行,未然形,終わる
1737 動詞,非自立,*,*,五段・ラ行,未然特殊,ある
1738 動詞,非自立,*,*,五段・ラ行,未然特殊,おる
1739 動詞,非自立,*,*,五段・ラ行,未然特殊,かかる
1740 動詞,非自立,*,*,五段・ラ行,未然特殊,きる
1741 動詞,非自立,*,*,五段・ラ行,未然特殊,たる
1742 動詞,非自立,*,*,五段・ラ行,未然特殊,とる
1743 動詞,非自立,*,*,五段・ラ行,未然特殊,どる
1744 動詞,非自立,*,*,五段・ラ行,未然特殊,なる
1745 動詞,非自立,*,*,五段・ラ行,未然特殊,はる
1746 動詞,非自立,*,*,五段・ラ行,未然特殊,まいる
1747 動詞,非自立,*,*,五段・ラ行,未然特殊,まくる
1748 動詞,非自立,*,*,五段・ラ行,未然特殊,まわる
1749 動詞,非自立,*,*,五段・ラ行,未然特殊,やがる
1750 動詞,非自立,*,*,五段・ラ行,未然特殊,やる
1751 動詞,非自立,*,*,五段・ラ行,未然特殊,切る
1752 動詞,非自立,*,*,五段・ラ行,未然特殊,参る
1753 動詞,非自立,*,*,五段・ラ行,未然特殊,回る
1754 動詞,非自立,*,*,五段・ラ行,未然特殊,終わる
1755 動詞,非自立,*,*,五段・ラ行,連用タ接続,ある
1756 動詞,非自立,*,*,五段・ラ行,連用タ接続,おる
1757 動詞,非自立,*,*,五段・ラ行,連用タ接続,かかる
1758 動詞,非自立,*,*,五段・ラ行,連用タ接続,きる
1759 動詞,非自立,*,*,五段・ラ行,連用タ接続,たる
1760 動詞,非自立,*,*,五段・ラ行,連用タ接続,とる
1761 動詞,非自立,*,*,五段・ラ行,連用タ接続,どる
1762 動詞,非自立,*,*,五段・ラ行,連用タ接続,なる
1763 動詞,非自立,*,*,五段・ラ行,連用タ接続,はる
1764 動詞,非自立,*,*,五段・ラ行,連用タ接続,まいる
1765 動詞,非自立,*,*,五段・ラ行,連用タ接続,まくる
1766 動詞,非自立,*,*,五段・ラ行,連用タ接続,まわる
1767 動詞,非自立,*,*,五段・ラ行,連用タ接続,やがる
1768 動詞,非自立,*,*,五段・ラ行,連用タ接続,やる
1769 動詞,非自立,*,*,五段・ラ行,連用タ接続,切る
1770 動詞,非自立,*,*,五段・ラ行,連用タ接続,参る
1771 動詞,非自立,*,*,五段・ラ行,連用タ接続,回る
1772 動詞,非自立,*,*,五段・ラ行,連用タ接続,終わる
1773 動詞,非自立,*,*,五段・ラ行,連用形,ある
1774 動詞,非自立,*,*,五段・ラ行,連用形,おる
1775 動詞,非自立,*,*,五段・ラ行,連用形,かかる
1776 動詞,非自立,*,*,五段・ラ行,連用形,きる
1777 動詞,非自立,*,*,五段・ラ行,連用形,たる
1778 動詞,非自立,*,*,五段・ラ行,連用形,とる
1779 動詞,非自立,*,*,五段・ラ行,連用形,どる
1780 動詞,非自立,*,*,五段・ラ行,連用形,なる
1781 動詞,非自立,*,*,五段・ラ行,連用形,はる
1782 動詞,非自立,*,*,五段・ラ行,連用形,まいる
1783 動詞,非自立,*,*,五段・ラ行,連用形,まくる
1784 動詞,非自立,*,*,五段・ラ行,連用形,まわる
1785 動詞,非自立,*,*,五段・ラ行,連用形,やがる
1786 動詞,非自立,*,*,五段・ラ行,連用形,やる
1787 動詞,非自立,*,*,五段・ラ行,連用形,ドル
1788 動詞,非自立,*,*,五段・ラ行,連用形,切る
1789 動詞,非自立,*,*,五段・ラ行,連用形,参る
1790 動詞,非自立,*,*,五段・ラ行,連用形,回る
1791 動詞,非自立,*,*,五段・ラ行,連用形,終わる
1792 動詞,非自立,*,*,五段・ラ行特殊,仮定形,いらっしゃる
1793 動詞,非自立,*,*,五段・ラ行特殊,仮定形,くださる
1794 動詞,非自立,*,*,五段・ラ行特殊,仮定形,なさる
1795 動詞,非自立,*,*,五段・ラ行特殊,仮定形,らっしゃる
1796 動詞,非自立,*,*,五段・ラ行特殊,仮定形,下さる
1797 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,いらっしゃる
1798 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,くださる
1799 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,なさる
1800 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,らっしゃる
1801 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,下さる
1802 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,いらっしゃる
1803 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,くださる
1804 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,なさる
1805 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,らっしゃる
1806 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,下さる
1807 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,いらっしゃる
1808 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,くださる
1809 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさぁる
1810 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさる
1811 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさーる
1812 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさ～る
1813 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,らっしゃる
1814 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,クダサル
1815 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,ナサル
1816 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,下さる
1817 動詞,非自立,*,*,五段・ラ行特殊,基本形,いらっしゃる
1818 動詞,非自立,*,*,五段・ラ行特殊,基本形,くださる
1819 動詞,非自立,*,*,五段・ラ行特殊,基本形,なさる
1820 動詞,非自立,*,*,五段・ラ行特殊,基本形,らっしゃる
1821 動詞,非自立,*,*,五段・ラ行特殊,基本形,下さる
1822 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,いらっしゃる
1823 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,くださる
1824 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,なさる
1825 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,らっしゃる
1826 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,下さる
1827 動詞,非自立,*,*,五段・ラ行特殊,未然形,いらっしゃる
1828 動詞,非自立,*,*,五段・ラ行特殊,未然形,くださる
1829 動詞,非自立,*,*,五段・ラ行特殊,未然形,なさる
1830 動詞,非自立,*,*,五段・ラ行特殊,未然形,らっしゃる
1831 動詞,非自立,*,*,五段・ラ行特殊,未然形,下さる
1832 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,いらっしゃる
1833 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,くださる
1834 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,なさる
1835 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,らっしゃる
1836 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,下さる
1837 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,いらっしゃる
1838 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,くださる
1839 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,なさる
1840 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,らっしゃる
1841 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,下さる
1842 動詞,非自立,*,*,五段・ラ行特殊,連用形,いらっしゃる
1843 動詞,非自立,*,*,五段・ラ行特殊,連用形,くださる
1844 動詞,非自立,*,*,五段・ラ行特殊,連用形,なさる
1845 動詞,非自立,*,*,五段・ラ行特殊,連用形,らっしゃる
1846 動詞,非自立,*,*,五段・ラ行特殊,連用形,ラッシャル
1847 動詞,非自立,*,*,五段・ラ行特殊,連用形,下さる
1848 動詞,非自立,*,*,五段・ワ行ウ音便,未然ウ接続,たまう
1849 動詞,非自立,*,*,五段・ワ行ウ音便,連用タ接続,給う
1850 動詞,非自立,*,*,五段・ワ行ウ音便,連用形,たまう
1851 動詞,非自立,*,*,五段・ワ行促音便,仮定形,あう
1852 動詞,非自立,*,*,五段・ワ行促音便,仮定形,しまう
1853 動詞,非自立,*,*,五段・ワ行促音便,仮定形,じまう
1854 動詞,非自立,*,*,五段・ワ行促音便,仮定形,じゃう
1855 動詞,非自立,*,*,五段・ワ行促音便,仮定形,たまう
1856 動詞,非自立,*,*,五段・ワ行促音便,仮定形,ちまう
1857 動詞,非自立,*,*,五段・ワ行促音便,仮定形,ちゃう
1858 動詞,非自立,*,*,五段・ワ行促音便,仮定形,もらう
1859 動詞,非自立,*,*,五段・ワ行促音便,仮定形,合う
1860 動詞,非自立,*,*,五段・ワ行促音便,仮定形,給う
1861 動詞,非自立,*,*,五段・ワ行促音便,仮定形,願う
1862 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,あう
1863 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,しまう
1864 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,じまう
1865 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,じゃう
1866 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,ちまう
1867 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,ちゃう
1868 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,もらう
1869 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,合う
1870 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,給う
1871 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,願う
1872 動詞,非自立,*,*,五段・ワ行促音便,基本形,あう
1873 動詞,非自立,*,*,五段・ワ行促音便,基本形,しまう
1874 動詞,非自立,*,*,五段・ワ行促音便,基本形,じまう
1875 動詞,非自立,*,*,五段・ワ行促音便,基本形,じゃう
1876 動詞,非自立,*,*,五段・ワ行促音便,基本形,たまう
1877 動詞,非自立,*,*,五段・ワ行促音便,基本形,ちまう
1878 動詞,非自立,*,*,五段・ワ行促音便,基本形,ちゃう
1879 動詞,非自立,*,*,五段・ワ行促音便,基本形,もらう
1880 動詞,非自立,*,*,五段・ワ行促音便,基本形,シマウ
1881 動詞,非自立,*,*,五段・ワ行促音便,基本形,合う
1882 動詞,非自立,*,*,五段・ワ行促音便,基本形,給う
1883 動詞,非自立,*,*,五段・ワ行促音便,基本形,願う
1884 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,あう
1885 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,しまう
1886 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,じまう
1887 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,じゃう
1888 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,たまう
1889 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,ちまう
1890 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,ちゃう
1891 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,もらう
1892 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,合う
1893 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,給う
1894 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,願う
1895 動詞,非自立,*,*,五段・ワ行促音便,未然形,あう
1896 動詞,非自立,*,*,五段・ワ行促音便,未然形,しまう
1897 動詞,非自立,*,*,五段・ワ行促音便,未然形,じまう
1898 動詞,非自立,*,*,五段・ワ行促音便,未然形,じゃう
1899 動詞,非自立,*,*,五段・ワ行促音便,未然形,たまう
1900 動詞,非自立,*,*,五段・ワ行促音便,未然形,ちまう
1901 動詞,非自立,*,*,五段・ワ行促音便,未然形,ちゃう
1902 動詞,非自立,*,*,五段・ワ行促音便,未然形,もらう
1903 動詞,非自立,*,*,五段・ワ行促音便,未然形,合う
1904 動詞,非自立,*,*,五段・ワ行促音便,未然形,給う
1905 動詞,非自立,*,*,五段・ワ行促音便,未然形,願う
1906 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,あう
1907 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,しまう
1908 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,じまう
1909 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,じゃう
1910 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,たまう
1911 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,ちまう
1912 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,ちゃう
1913 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,もらう
1914 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,シマウ
1915 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,合う
1916 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,給う
1917 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,願う
1918 動詞,非自立,*,*,五段・ワ行促音便,連用形,あう
1919 動詞,非自立,*,*,五段・ワ行促音便,連用形,しまう
1920 動詞,非自立,*,*,五段・ワ行促音便,連用形,じまう
1921 動詞,非自立,*,*,五段・ワ行促音便,連用形,じゃう
1922 動詞,非自立,*,*,五段・ワ行促音便,連用形,たまう
1923 動詞,非自立,*,*,五段・ワ行促音便,連用形,ちまう
1924 動詞,非自立,*,*,五段・ワ行促音便,連用形,ちゃう
1925 動詞,非自立,*,*,五段・ワ行促音便,連用形,もらう
1926 動詞,非自立,*,*,五段・ワ行促音便,連用形,合う
1927 動詞,非自立,*,*,五段・ワ行促音便,連用形,給う
1928 動詞,非自立,*,*,五段・ワ行促音便,連用形,願う
1929 動詞,非自立,*,*,四段・ハ行,仮定形,しまふ
1930 動詞,非自立,*,*,四段・ハ行,命令ｅ,しまふ
1931 動詞,非自立,*,*,四段・ハ行,基本形,しまふ
1932 動詞,非自立,*,*,四段・ハ行,未然形,しまふ
1933 動詞,非自立,*,*,四段・ハ行,連用形,しまふ
1934 名詞,サ変接続,*,*,*,*,*
1935 名詞,サ変接続,*,*,*,*,*,使用
1936 名詞,サ変接続,*,*,*,*,*,試用
1937 名詞,サ変接続,*,*,*,*,話
1938 名詞,ナイ形容詞語幹,*,*,*,*,*
1939 名詞,一般,*,*,*,*,*
1940 名詞,一般,*,*,*,*,*,あと
1941 名詞,一般,*,*,*,*,*,こ
1942 名詞,一般,*,*,*,*,*,ほん
1943 名詞,一般,*,*,*,*,*,上
1944 名詞,一般,*,*,*,*,*,下
1945 名詞,一般,*,*,*,*,*,下記
1946 名詞,一般,*,*,*,*,*,事故
1947 名詞,一般,*,*,*,*,*,仕様
1948 名詞,一般,*,*,*,*,*,他
1949 名詞,一般,*,*,*,*,*,件
1950 名詞,一般,*,*,*,*,*,例
1951 名詞,一般,*,*,*,*,*,先
1952 名詞,一般,*,*,*,*,*,北
1953 名詞,一般,*,*,*,*,*,危機
1954 名詞,一般,*,*,*,*,*,口座
1955 名詞,一般,*,*,*,*,*,地震
1956 名詞,一般,*,*,*,*,*,声
1957 名詞,一般,*,*,*,*,*,女史
1958 名詞,一般,*,*,*,*,*,女子
1959 名詞,一般,*,*,*,*,*,子
1960 名詞,一般,*,*,*,*,*,家
1961 名詞,一般,*,*,*,*,*,家庭
1962 名詞,一般,*,*,*,*,*,年
1963 名詞,一般,*,*,*,*,*,得
1964 名詞,一般,*,*,*,*,*,手
1965 名詞,一般,*,*,*,*,*,月
1966 名詞,一般,*,*,*,*,*,期間
1967 名詞,一般,*,*,*,*,*,木
1968 名詞,一般,*,*,*,*,*,本
1969 名詞,一般,*,*,*,*,*,機会
1970 名詞,一般,*,*,*,*,*,機器
1971 名詞,一般,*,*,*,*,*,機械
1972 名詞,一般,*,*,*,*,*,機関
1973 名詞,一般,*,*,*,*,*,次
1974 名詞,一般,*,*,*,*,*,気
1975 名詞,一般,*,*,*,*,*,無
1976 名詞,一般,*,*,*,*,*,目
1977 名詞,一般,*,*,*,*,*,自己
1978 名詞,一般,*,*,*,*,*,自身
1979 名詞,一般,*,*,*,*,*,色
1980 名詞,一般,*,*,*,*,*,課程
1981 名詞,一般,*,*,*,*,*,講座
1982 名詞,一般,*,*,*,*,*,過程
1983 名詞,一般,*,*,*,*,*,間
1984 名詞,一般,*,*,*,*,*,音
1985 名詞,一般,*,*,*,*,*,顔
1986 名詞,一般,*,*,*,*,*,駅
1987 名詞,代名詞,一般,*,*,*,*
1988 名詞,代名詞,一般,*,*,わたし
1989 名詞,代名詞,一般,*,*,私
1990 名詞,代名詞,副詞可能,*,*,*,*
1991 名詞,代名詞,副詞可能,時間,*,*,*
1992 名詞,代名詞,場所,*,*,*,*
1993 名詞,代名詞,対象,*,*,*,*
1994 名詞,代名詞,対象・場所,*,*,*,*
1995 名詞,代名詞,縮約,*,*,*,*
1996 名詞,副詞可能,*,*,*,*,*
1997 名詞,副詞可能,*,*,*,*,いま
1998 名詞,副詞可能,*,*,*,*,すべて
1999 名詞,副詞可能,*,*,*,*,今
2000 名詞,副詞可能,*,*,*,*,今日
2001 名詞,副詞可能,*,*,*,*,前
2002 名詞,副詞可能,*,*,*,*,場合
2003 名詞,副詞可能,*,*,*,*,時間
2004 名詞,副詞可能,*,*,*,*,現在
2005 名詞,副詞可能,*,*,*,*,結果
2006 名詞,動詞非自立的,*,*,*,*,*
2007 名詞,固有名詞,一般,*,*,*,*
2008 名詞,固有名詞,人名,一般,*,*,*
2009 名詞,固有名詞,人名,名,*,*,*
2010 名詞,固有名詞,人名,姓,*,*,*
2011 名詞,固有名詞,地域,一般,*,*,*
2012 名詞,固有名詞,地域,一般,*,*,府名
2013 名詞,固有名詞,地域,一般,*,*,県名
2014 名詞,固有名詞,地域,一般,*,*,都名
2015 名詞,固有名詞,地域,国,*,*,*
2016 名詞,固有名詞,組織,*,*,*,*
2017 名詞,引用文字列,*,*,*,*,*
2018 名詞,形容動詞語幹,*,*,*,*,*
2019 名詞,接尾,サ変接続,*,*,*,*
2020 名詞,接尾,サ変接続,*,*,*,入り
2021 名詞,接尾,サ変接続,*,*,*,化
2022 名詞,接尾,サ変接続,*,*,*,視
2023 名詞,接尾,サ変接続,*,*,*,話
2024 名詞,接尾,一般,*,*,*,*
2025 名詞,接尾,人名,*,*,*,*
2026 名詞,接尾,副詞可能,*,*,*,*
2027 名詞,接尾,助動詞語幹,*,*,*,*
2028 名詞,接尾,助数詞,*,*,*,*
2029 名詞,接尾,地域,*,*,*,*
2030 名詞,接尾,地域,*,*,*,区
2031 名詞,接尾,地域,*,*,*,市
2032 名詞,接尾,地域,*,*,*,府
2033 名詞,接尾,地域,*,*,*,村
2034 名詞,接尾,地域,*,*,*,町
2035 名詞,接尾,地域,*,*,*,県
2036 名詞,接尾,地域,*,*,*,郡
2037 名詞,接尾,地域,*,*,*,駅
2038 名詞,接尾,形容動詞語幹,*,*,*,*
2039 名詞,接尾,形容動詞語幹,*,*,*,がち
2040 名詞,接尾,形容動詞語幹,*,*,*,好き
2041 名詞,接尾,形容動詞語幹,*,*,*,的
2042 名詞,接尾,特殊,*,*,*,*
2043 名詞,接尾可能,人名,*,*,*,*
2044 名詞,接尾可能,人名,*,*,*,女史
2045 名詞,接続詞的,*,*,*,*,*
2046 名詞,数,*,*,*,*,*
2047 名詞,数,アラビア数字
2048 名詞,数,区切り文字
2049 名詞,数,漢数字,*,*,*,*
2050 名詞,数,漢数字,*,*,*,万
2051 名詞,数,漢数字,*,*,*,京
2052 名詞,数,漢数字,*,*,*,億
2053 名詞,数,漢数字,*,*,*,兆
2054 名詞,数,漢数字,*,*,*,十
2055 名詞,数,漢数字,*,*,*,千
2056 名詞,数,漢数字,*,*,*,百
2057 名詞,特殊,助動詞語幹,*,*,*,*
2058 名詞,非自立,*,*,*,*,やつ
2059 名詞,非自立,*,*,*,*,奴
2060 名詞,非自立,一般,*,*,*,あまり
2061 名詞,非自立,一般,*,*,*,うえ
2062 名詞,非自立,一般,*,*,*,うち
2063 名詞,非自立,一般,*,*,*,かい
2064 名詞,非自立,一般,*,*,*,かけ
2065 名詞,非自立,一般,*,*,*,かた
2066 名詞,非自立,一般,*,*,*,がい
2067 名詞,非自立,一般,*,*,*,きらい
2068 名詞,非自立,一般,*,*,*,くせ
2069 名詞,非自立,一般,*,*,*,こと
2070 名詞,非自立,一般,*,*,*,こなし
2071 名詞,非自立,一般,*,*,*,さし
2072 名詞,非自立,一般,*,*,*,さま
2073 名詞,非自立,一般,*,*,*,さら
2074 名詞,非自立,一般,*,*,*,すえ
2075 名詞,非自立,一般,*,*,*,すべ
2076 名詞,非自立,一般,*,*,*,せい
2077 名詞,非自立,一般,*,*,*,たか
2078 名詞,非自立,一般,*,*,*,たぐい
2079 名詞,非自立,一般,*,*,*,ため
2080 名詞,非自立,一般,*,*,*,つもり
2081 名詞,非自立,一般,*,*,*,とき
2082 名詞,非自立,一般,*,*,*,どころ
2083 名詞,非自立,一般,*,*,*,の
2084 名詞,非自立,一般,*,*,*,のん
2085 名詞,非自立,一般,*,*,*,はず
2086 名詞,非自立,一般,*,*,*,はずみ
2087 名詞,非自立,一般,*,*,*,ふし
2088 名詞,非自立,一般,*,*,*,ふり
2089 名詞,非自立,一般,*,*,*,へん
2090 名詞,非自立,一般,*,*,*,ほう
2091 名詞,非自立,一般,*,*,*,ほど
2092 名詞,非自立,一般,*,*,*,もと
2093 名詞,非自立,一般,*,*,*,もの
2094 名詞,非自立,一般,*,*,*,もん
2095 名詞,非自立,一般,*,*,*,わけ
2096 名詞,非自立,一般,*,*,*,ん
2097 名詞,非自立,一般,*,*,*,コト
2098 名詞,非自立,一般,*,*,*,ツモリ
2099 名詞,非自立,一般,*,*,*,ドコロ
2100 名詞,非自立,一般,*,*,*,フシ
2101 名詞,非自立,一般,*,*,*,ホ
2102 名詞,非自立,一般,*,*,*,モノ
2103 名詞,非自立,一般,*,*,*,ン
2104 名詞,非自立,一般,*,*,*,下
2105 名詞,非自立,一般,*,*,*,事
2106 名詞,非自立,一般,*,*,*,以北
2107 名詞,非自立,一般,*,*,*,以南
2108 名詞,非自立,一般,*,*,*,作
2109 名詞,非自立,一般,*,*,*,側
2110 名詞,非自立,一般,*,*,*,割
2111 名詞,非自立,一般,*,*,*,半
2112 名詞,非自立,一般,*,*,*,場
2113 名詞,非自立,一般,*,*,*,折
2114 名詞,非自立,一般,*,*,*,故
2115 名詞,非自立,一般,*,*,*,方
2116 名詞,非自立,一般,*,*,*,日
2117 名詞,非自立,一般,*,*,*,旨
2118 名詞,非自立,一般,*,*,*,時
2119 名詞,非自立,一般,*,*,*,機
2120 名詞,非自立,一般,*,*,*,気
2121 名詞,非自立,一般,*,*,*,点
2122 名詞,非自立,一般,*,*,*,物
2123 名詞,非自立,一般,*,*,*,生み
2124 名詞,非自立,一般,*,*,*,目
2125 名詞,非自立,一般,*,*,*,程
2126 名詞,非自立,一般,*,*,*,種
2127 名詞,非自立,一般,*,*,*,筈
2128 名詞,非自立,一般,*,*,*,者
2129 名詞,非自立,一般,*,*,*,訳
2130 名詞,非自立,副詞可能,*,*,*,あまり
2131 名詞,非自立,副詞可能,*,*,*,うえ
2132 名詞,非自立,副詞可能,*,*,*,うち
2133 名詞,非自立,副詞可能,*,*,*,かぎり
2134 名詞,非自立,副詞可能,*,*,*,かた
2135 名詞,非自立,副詞可能,*,*,*,きり
2136 名詞,非自立,副詞可能,*,*,*,ころ
2137 名詞,非自立,副詞可能,*,*,*,ごと
2138 名詞,非自立,副詞可能,*,*,*,さなか
2139 名詞,非自立,副詞可能,*,*,*,たび
2140 名詞,非自立,副詞可能,*,*,*,ため
2141 名詞,非自立,副詞可能,*,*,*,っきり
2142 名詞,非自立,副詞可能,*,*,*,ついで
2143 名詞,非自立,副詞可能,*,*,*,つど
2144 名詞,非自立,副詞可能,*,*,*,とおり
2145 名詞,非自立,副詞可能,*,*,*,とき
2146 名詞,非自立,副詞可能,*,*,*,ところ
2147 名詞,非自立,副詞可能,*,*,*,とたん
2148 名詞,非自立,副詞可能,*,*,*,なか
2149 名詞,非自立,副詞可能,*,*,*,のち
2150 名詞,非自立,副詞可能,*,*,*,はじめ
2151 名詞,非自立,副詞可能,*,*,*,はず
2152 名詞,非自立,副詞可能,*,*,*,ほど
2153 名詞,非自立,副詞可能,*,*,*,まま
2154 名詞,非自立,副詞可能,*,*,*,まんま
2155 名詞,非自立,副詞可能,*,*,*,ゆえ
2156 名詞,非自立,副詞可能,*,*,*,トコロ
2157 名詞,非自立,副詞可能,*,*,*,マンマ
2158 名詞,非自立,副詞可能,*,*,*,一方
2159 名詞,非自立,副詞可能,*,*,*,上
2160 名詞,非自立,副詞可能,*,*,*,下
2161 名詞,非自立,副詞可能,*,*,*,中
2162 名詞,非自立,副詞可能,*,*,*,他
2163 名詞,非自立,副詞可能,*,*,*,以上
2164 名詞,非自立,副詞可能,*,*,*,以内
2165 名詞,非自立,副詞可能,*,*,*,以外
2166 名詞,非自立,副詞可能,*,*,*,以後
2167 名詞,非自立,副詞可能,*,*,*,以降
2168 名詞,非自立,副詞可能,*,*,*,内
2169 名詞,非自立,副詞可能,*,*,*,初め
2170 名詞,非自立,副詞可能,*,*,*,夕
2171 名詞,非自立,副詞可能,*,*,*,外
2172 名詞,非自立,副詞可能,*,*,*,家
2173 名詞,非自立,副詞可能,*,*,*,度
2174 名詞,非自立,副詞可能,*,*,*,後
2175 名詞,非自立,副詞可能,*,*,*,後半
2176 名詞,非自立,副詞可能,*,*,*,所
2177 名詞,非自立,副詞可能,*,*,*,折
2178 名詞,非自立,副詞可能,*,*,*,故
2179 名詞,非自立,副詞可能,*,*,*,日
2180 名詞,非自立,副詞可能,*,*,*,時
2181 名詞,非自立,副詞可能,*,*,*,未満
2182 名詞,非自立,副詞可能,*,*,*,末
2183 名詞,非自立,副詞可能,*,*,*,毎
2184 名詞,非自立,副詞可能,*,*,*,為
2185 名詞,非自立,副詞可能,*,*,*,矢先
2186 名詞,非自立,副詞可能,*,*,*,自身
2187 名詞,非自立,副詞可能,*,*,*,途端
2188 名詞,非自立,副詞可能,*,*,*,都度
2189 名詞,非自立,副詞可能,*,*,*,限り
2190 名詞,非自立,副詞可能,*,*,*,際
2191 名詞,非自立,副詞可能,*,*,*,頃
2192 名詞,非自立,助動詞語幹,*,*,*,やう
2193 名詞,非自立,助動詞語幹,*,*,*,よ
2194 名詞,非自立,助動詞語幹,*,*,*,よう
2195 名詞,非自立,助動詞語幹,*,*,*,様
2196 名詞,非自立,形容動詞語幹,*,*,*,ふう
2197 名詞,非自立,形容動詞語幹,*,*,*,みたい
2198 形容詞,接尾,*,*,*,文語基本形,*,*
2199 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,くさい
2200 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,っぽい
2201 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,ぽい
2202 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,深い
2203 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,臭い
2204 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,くさい
2205 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,っぽい
2206 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,ぽい
2207 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,深い
2208 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,臭い
2209 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,くさい
2210 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,っぽい
2211 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,ぽい
2212 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,深い
2213 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,臭い
2214 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,くさい
2215 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,っぽい
2216 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,ぽい
2217 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,深い
2218 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,臭い
2219 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,くさい
2220 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,っぽい
2221 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,ぽい
2222 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,ポイ
2223 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,深い
2224 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,臭い
2225 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,くさい
2226 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,っぽい
2227 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,ぽい
2228 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,深い
2229 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,臭い
2230 形容詞,接尾,*,*,形容詞・アウオ段,基本形,くさい
2231 形容詞,接尾,*,*,形容詞・アウオ段,基本形,っぽい
2232 形容詞,接尾,*,*,形容詞・アウオ段,基本形,ぽい
2233 形容詞,接尾,*,*,形容詞・アウオ段,基本形,深い
2234 形容詞,接尾,*,*,形容詞・アウオ段,基本形,臭い
2235 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,くさい
2236 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,っぽい
2237 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,ぽい
2238 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,深い
2239 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,臭い
2240 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,くさい
2241 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,っぽい
2242 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,ぽい
2243 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,深い
2244 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,臭い
2245 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,くさい
2246 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,っぽい
2247 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,ぽい
2248 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,ポイ
2249 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,深い
2250 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,臭い
2251 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,くさい
2252 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,っぽい
2253 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,ぽい
2254 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,深い
2255 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,臭い
2256 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,くさい
2257 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,っぽい
2258 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,ぽい
2259 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,深い
2260 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,臭い
2261 形容詞,接尾,*,*,形容詞・イ段,ガル接続,たらしい
2262 形容詞,接尾,*,*,形容詞・イ段,ガル接続,ったらしい
2263 形容詞,接尾,*,*,形容詞・イ段,仮定形,たらしい
2264 形容詞,接尾,*,*,形容詞・イ段,仮定形,ったらしい
2265 形容詞,接尾,*,*,形容詞・イ段,仮定縮約１,たらしい
2266 形容詞,接尾,*,*,形容詞・イ段,仮定縮約１,ったらしい
2267 形容詞,接尾,*,*,形容詞・イ段,仮定縮約２,たらしい
2268 形容詞,接尾,*,*,形容詞・イ段,仮定縮約２,ったらしい
2269 形容詞,接尾,*,*,形容詞・イ段,体言接続,たらしい
2270 形容詞,接尾,*,*,形容詞・イ段,体言接続,ったらしい
2271 形容詞,接尾,*,*,形容詞・イ段,命令ｅ,たらしい
2272 形容詞,接尾,*,*,形容詞・イ段,命令ｅ,ったらしい
2273 形容詞,接尾,*,*,形容詞・イ段,基本形,たらしい
2274 形容詞,接尾,*,*,形容詞・イ段,基本形,ったらしい
2275 形容詞,接尾,*,*,形容詞・イ段,未然ウ接続,たらしい
2276 形容詞,接尾,*,*,形容詞・イ段,未然ウ接続,ったらしい
2277 形容詞,接尾,*,*,形容詞・イ段,未然ヌ接続,たらしい
2278 形容詞,接尾,*,*,形容詞・イ段,未然ヌ接続,ったらしい
2279 形容詞,接尾,*,*,形容詞・イ段,連用ゴザイ接続,たらしい
2280 形容詞,接尾,*,*,形容詞・イ段,連用ゴザイ接続,ったらしい
2281 形容詞,接尾,*,*,形容詞・イ段,連用タ接続,たらしい
2282 形容詞,接尾,*,*,形容詞・イ段,連用タ接続,ったらしい
2283 形容詞,接尾,*,*,形容詞・イ段,連用テ接続,たらしい
2284 形容詞,接尾,*,*,形容詞・イ段,連用テ接続,ったらしい
2285 形容詞,自立,*,*,*,文語基本形,*,*
2286 形容詞,自立,*,*,不変化型,基本形,*
2287 形容詞,自立,*,*,不変化型,基本形,6
2288 形容詞,自立,*,*,不変化型,基本形,7
2289 形容詞,自立,*,*,不変化型,基本形,8
2290 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,*
2291 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,1
2292 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,2
2293 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,3
2294 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,4
2295 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,5
2296 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,6
2297 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,7
2298 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,8
2299 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,ない
2300 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,よい
2301 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,無い
2302 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,良い
2303 形容詞,自立,*,*,形容詞・アウオ段,仮定形,*
2304 形容詞,自立,*,*,形容詞・アウオ段,仮定形,1
2305 形容詞,自立,*,*,形容詞・アウオ段,仮定形,2
2306 形容詞,自立,*,*,形容詞・アウオ段,仮定形,3
2307 形容詞,自立,*,*,形容詞・アウオ段,仮定形,4
2308 形容詞,自立,*,*,形容詞・アウオ段,仮定形,5
2309 形容詞,自立,*,*,形容詞・アウオ段,仮定形,6
2310 形容詞,自立,*,*,形容詞・アウオ段,仮定形,7
2311 形容詞,自立,*,*,形容詞・アウオ段,仮定形,8
2312 形容詞,自立,*,*,形容詞・アウオ段,仮定形,ない
2313 形容詞,自立,*,*,形容詞・アウオ段,仮定形,よい
2314 形容詞,自立,*,*,形容詞・アウオ段,仮定形,無い
2315 形容詞,自立,*,*,形容詞・アウオ段,仮定形,良い
2316 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,*
2317 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,1
2318 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,2
2319 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,3
2320 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,4
2321 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,5
2322 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,6
2323 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,7
2324 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,8
2325 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,ない
2326 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,よい
2327 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,無い
2328 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,良い
2329 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,*
2330 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,1
2331 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,2
2332 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,3
2333 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,4
2334 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,5
2335 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,6
2336 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,7
2337 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,8
2338 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,ない
2339 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,よい
2340 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,無い
2341 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,良い
2342 形容詞,自立,*,*,形容詞・アウオ段,体言接続,*
2343 形容詞,自立,*,*,形容詞・アウオ段,体言接続,1
2344 形容詞,自立,*,*,形容詞・アウオ段,体言接続,2
2345 形容詞,自立,*,*,形容詞・アウオ段,体言接続,3
2346 形容詞,自立,*,*,形容詞・アウオ段,体言接続,4
2347 形容詞,自立,*,*,形容詞・アウオ段,体言接続,5
2348 形容詞,自立,*,*,形容詞・アウオ段,体言接続,6
2349 形容詞,自立,*,*,形容詞・アウオ段,体言接続,7
2350 形容詞,自立,*,*,形容詞・アウオ段,体言接続,8
2351 形容詞,自立,*,*,形容詞・アウオ段,体言接続,ない
2352 形容詞,自立,*,*,形容詞・アウオ段,体言接続,よい
2353 形容詞,自立,*,*,形容詞・アウオ段,体言接続,無い
2354 形容詞,自立,*,*,形容詞・アウオ段,体言接続,良い
2355 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,*
2356 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,1
2357 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,2
2358 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,3
2359 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,4
2360 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,5
2361 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,6
2362 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,7
2363 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,8
2364 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,ない
2365 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,よい
2366 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,無い
2367 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,良い
2368 形容詞,自立,*,*,形容詞・アウオ段,基本形,*
2369 形容詞,自立,*,*,形容詞・アウオ段,基本形,1
2370 形容詞,自立,*,*,形容詞・アウオ段,基本形,2
2371 形容詞,自立,*,*,形容詞・アウオ段,基本形,3
2372 形容詞,自立,*,*,形容詞・アウオ段,基本形,4
2373 形容詞,自立,*,*,形容詞・アウオ段,基本形,5
2374 形容詞,自立,*,*,形容詞・アウオ段,基本形,6
2375 形容詞,自立,*,*,形容詞・アウオ段,基本形,7
2376 形容詞,自立,*,*,形容詞・アウオ段,基本形,8
2377 形容詞,自立,*,*,形容詞・アウオ段,基本形,ない
2378 形容詞,自立,*,*,形容詞・アウオ段,基本形,よい
2379 形容詞,自立,*,*,形容詞・アウオ段,基本形,無い
2380 形容詞,自立,*,*,形容詞・アウオ段,基本形,良い
2381 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,*
2382 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,1
2383 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,2
2384 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,3
2385 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,4
2386 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,5
2387 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,6
2388 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,7
2389 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,8
2390 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,ない
2391 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,よい
2392 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,無い
2393 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,良い
2394 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,*
2395 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,1
2396 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,2
2397 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,3
2398 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,4
2399 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,5
2400 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,6
2401 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,7
2402 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,8
2403 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,ない
2404 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,よい
2405 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,無い
2406 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,良い
2407 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,*
2408 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,1
2409 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,2
2410 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,3
2411 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,4
2412 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,5
2413 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,6
2414 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,7
2415 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,8
2416 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,ない
2417 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,よい
2418 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,無い
2419 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,良い
2420 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,*
2421 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,1
2422 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,2
2423 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,3
2424 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,4
2425 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,5
2426 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,6
2427 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,7
2428 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,8
2429 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,ない
2430 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,よい
2431 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,無い
2432 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,良い
2433 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,*
2434 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,1
2435 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,2
2436 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,3
2437 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,4
2438 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,5
2439 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,6
2440 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,7
2441 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,8
2442 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,ない
2443 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,よい
2444 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,無い
2445 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,良い
2446 形容詞,自立,*,*,形容詞・イ段,ガル接続,*
2447 形容詞,自立,*,*,形容詞・イ段,ガル接続,1
2448 形容詞,自立,*,*,形容詞・イ段,ガル接続,2
2449 形容詞,自立,*,*,形容詞・イ段,ガル接続,3
2450 形容詞,自立,*,*,形容詞・イ段,ガル接続,4
2451 形容詞,自立,*,*,形容詞・イ段,ガル接続,5
2452 形容詞,自立,*,*,形容詞・イ段,ガル接続,6
2453 形容詞,自立,*,*,形容詞・イ段,ガル接続,7
2454 形容詞,自立,*,*,形容詞・イ段,ガル接続,8
2455 形容詞,自立,*,*,形容詞・イ段,仮定形,*
2456 形容詞,自立,*,*,形容詞・イ段,仮定形,1
2457 形容詞,自立,*,*,形容詞・イ段,仮定形,2
2458 形容詞,自立,*,*,形容詞・イ段,仮定形,3
2459 形容詞,自立,*,*,形容詞・イ段,仮定形,4
2460 形容詞,自立,*,*,形容詞・イ段,仮定形,5
2461 形容詞,自立,*,*,形容詞・イ段,仮定形,6
2462 形容詞,自立,*,*,形容詞・イ段,仮定形,7
2463 形容詞,自立,*,*,形容詞・イ段,仮定形,8
2464 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,*
2465 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,1
2466 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,2
2467 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,3
2468 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,4
2469 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,5
2470 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,6
2471 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,7
2472 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,8
2473 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,*
2474 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,1
2475 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,2
2476 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,3
2477 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,4
2478 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,5
2479 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,6
2480 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,7
2481 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,8
2482 形容詞,自立,*,*,形容詞・イ段,体言接続,*
2483 形容詞,自立,*,*,形容詞・イ段,体言接続,1
2484 形容詞,自立,*,*,形容詞・イ段,体言接続,2
2485 形容詞,自立,*,*,形容詞・イ段,体言接続,3
2486 形容詞,自立,*,*,形容詞・イ段,体言接続,4
2487 形容詞,自立,*,*,形容詞・イ段,体言接続,5
2488 形容詞,自立,*,*,形容詞・イ段,体言接続,6
2489 形容詞,自立,*,*,形容詞・イ段,体言接続,7
2490 形容詞,自立,*,*,形容詞・イ段,体言接続,8
2491 形容詞,自立,*,*,形容詞・イ段,命令ｅ,*
2492 形容詞,自立,*,*,形容詞・イ段,命令ｅ,1
2493 形容詞,自立,*,*,形容詞・イ段,命令ｅ,2
2494 形容詞,自立,*,*,形容詞・イ段,命令ｅ,3
2495 形容詞,自立,*,*,形容詞・イ段,命令ｅ,4
2496 形容詞,自立,*,*,形容詞・イ段,命令ｅ,5
2497 形容詞,自立,*,*,形容詞・イ段,命令ｅ,6
2498 形容詞,自立,*,*,形容詞・イ段,命令ｅ,7
2499 形容詞,自立,*,*,形容詞・イ段,命令ｅ,8
2500 形容詞,自立,*,*,形容詞・イ段,基本形,*
2501 形容詞,自立,*,*,形容詞・イ段,基本形,1
2502 形容詞,自立,*,*,形容詞・イ段,基本形,2
2503 形容詞,自立,*,*,形容詞・イ段,基本形,3
2504 形容詞,自立,*,*,形容詞・イ段,基本形,4
2505 形容詞,自立,*,*,形容詞・イ段,基本形,5
2506 形容詞,自立,*,*,形容詞・イ段,基本形,6
2507 形容詞,自立,*,*,形容詞・イ段,基本形,7
2508 形容詞,自立,*,*,形容詞・イ段,基本形,8
2509 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,*
2510 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,1
2511 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,2
2512 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,3
2513 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,4
2514 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,5
2515 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,6
2516 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,7
2517 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,8
2518 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,*
2519 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,1
2520 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,2
2521 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,3
2522 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,4
2523 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,5
2524 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,6
2525 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,7
2526 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,8
2527 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,*
2528 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,1
2529 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,2
2530 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,3
2531 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,4
2532 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,5
2533 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,6
2534 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,7
2535 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,8
2536 形容詞,自立,*,*,形容詞・イ段,連用タ接続,*
2537 形容詞,自立,*,*,形容詞・イ段,連用タ接続,1
2538 形容詞,自立,*,*,形容詞・イ段,連用タ接続,2
2539 形容詞,自立,*,*,形容詞・イ段,連用タ接続,3
2540 形容詞,自立,*,*,形容詞・イ段,連用タ接続,4
2541 形容詞,自立,*,*,形容詞・イ段,連用タ接続,5
2542 形容詞,自立,*,*,形容詞・イ段,連用タ接続,6
2543 形容詞,自立,*,*,形容詞・イ段,連用タ接続,7
2544 形容詞,自立,*,*,形容詞・イ段,連用タ接続,8
2545 形容詞,自立,*,*,形容詞・イ段,連用テ接続,*
2546 形容詞,自立,*,*,形容詞・イ段,連用テ接続,1
2547 形容詞,自立,*,*,形容詞・イ段,連用テ接続,2
2548 形容詞,自立,*,*,形容詞・イ段,連用テ接続,3
2549 形容詞,自立,*,*,形容詞・イ段,連用テ接続,4
2550 形容詞,自立,*,*,形容詞・イ段,連用テ接続,5
2551 形容詞,自立,*,*,形容詞・イ段,連用テ接続,6
2552 形容詞,自立,*,*,形容詞・イ段,連用テ接続,7
2553 形容詞,自立,*,*,形容詞・イ段,連用テ接続,8
2554 形容詞,非自立,*,*,*,文語基本形,*,*
2555 形容詞,非自立,*,*,不変化型,基本形,いい
2556 形容詞,非自立,*,*,不変化型,基本形,イイ
2557 形容詞,非自立,*,*,不変化型,基本形-促音便,いい
2558 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,がたい
2559 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,づらい
2560 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,にくい
2561 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,やすい
2562 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,よい
2563 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,良い
2564 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,難い
2565 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,がたい
2566 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,づらい
2567 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,にくい
2568 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,やすい
2569 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,よい
2570 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,良い
2571 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,難い
2572 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,がたい
2573 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,づらい
2574 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,にくい
2575 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,やすい
2576 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,よい
2577 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,良い
2578 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,難い
2579 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,がたい
2580 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,づらい
2581 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,にくい
2582 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,やすい
2583 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,よい
2584 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,良い
2585 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,難い
2586 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,がたい
2587 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,づらい
2588 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,にくい
2589 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,やすい
2590 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,よい
2591 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,良い
2592 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,難い
2593 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,がたい
2594 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,づらい
2595 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,にくい
2596 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,やすい
2597 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,よい
2598 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,良い
2599 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,難い
2600 形容詞,非自立,*,*,形容詞・アウオ段,基本形,がたい
2601 形容詞,非自立,*,*,形容詞・アウオ段,基本形,づらい
2602 形容詞,非自立,*,*,形容詞・アウオ段,基本形,にくい
2603 形容詞,非自立,*,*,形容詞・アウオ段,基本形,やすい
2604 形容詞,非自立,*,*,形容詞・アウオ段,基本形,よい
2605 形容詞,非自立,*,*,形容詞・アウオ段,基本形,ヅライ
2606 形容詞,非自立,*,*,形容詞・アウオ段,基本形,良い
2607 形容詞,非自立,*,*,形容詞・アウオ段,基本形,難い
2608 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,がたい
2609 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,づらい
2610 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,にくい
2611 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,やすい
2612 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,よい
2613 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,良い
2614 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,難い
2615 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,がたい
2616 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,づらい
2617 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,にくい
2618 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,やすい
2619 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,よい
2620 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,良い
2621 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,難い
2622 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,がたい
2623 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,づらい
2624 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,にくい
2625 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,やすい
2626 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,よい
2627 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,良い
2628 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,難い
2629 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,がたい
2630 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,づらい
2631 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,にくい
2632 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,やすい
2633 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,よい
2634 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,良い
2635 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,難い
2636 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,がたい
2637 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,づらい
2638 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,にくい
2639 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,やすい
2640 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,よい
2641 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,良い
2642 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,難い
2643 形容詞,非自立,*,*,形容詞・イ段,ガル接続,ほしい
2644 形容詞,非自立,*,*,形容詞・イ段,ガル接続,欲しい
2645 形容詞,非自立,*,*,形容詞・イ段,仮定形,ほしい
2646 形容詞,非自立,*,*,形容詞・イ段,仮定形,欲しい
2647 形容詞,非自立,*,*,形容詞・イ段,仮定縮約１,ほしい
2648 形容詞,非自立,*,*,形容詞・イ段,仮定縮約１,欲しい
2649 形容詞,非自立,*,*,形容詞・イ段,仮定縮約２,ほしい
2650 形容詞,非自立,*,*,形容詞・イ段,仮定縮約２,欲しい
2651 形容詞,非自立,*,*,形容詞・イ段,体言接続,ほしい
2652 形容詞,非自立,*,*,形容詞・イ段,体言接続,欲しい
2653 形容詞,非自立,*,*,形容詞・イ段,命令ｅ,ほしい
2654 形容詞,非自立,*,*,形容詞・イ段,命令ｅ,欲しい
2655 形容詞,非自立,*,*,形容詞・イ段,基本形,ほしい
2656 形容詞,非自立,*,*,形容詞・イ段,基本形,欲しい
2657 形容詞,非自立,*,*,形容詞・イ段,未然ウ接続,ほしい
2658 形容詞,非自立,*,*,形容詞・イ段,未然ウ接続,欲しい
2659 形容詞,非自立,*,*,形容詞・イ段,未然ヌ接続,ほしい
2660 形容詞,非自立,*,*,形容詞・イ段,未然ヌ接続,欲しい
2661 形容詞,非自立,*,*,形容詞・イ段,連用ゴザイ接続,ほしい
2662 形容詞,非自立,*,*,形容詞・イ段,連用ゴザイ接続,欲しい
2663 形容詞,非自立,*,*,形容詞・イ段,連用タ接続,ほしい
2664 形容詞,非自立,*,*,形容詞・イ段,連用タ接続,欲しい
2665 形容詞,非自立,*,*,形容詞・イ段,連用テ接続,ほしい
2666 形容詞,非自立,*,*,形容詞・イ段,連用テ接続,欲しい
2667 感動詞,*,*,*,*,*,*
2668 接続詞,*,*,*,*,*,*
2669 接頭詞,丁寧連用形接続,*,*,*,*,*,*
2670 接頭詞,動詞接続,*,*,*,*,*,*
2671 接頭詞,名詞接続,*,*,*,*,*,*
2672 接頭詞,名詞接続,*,*,*,*,*,お
2673 接頭詞,名詞接続,*,*,*,*,*,ご
2674 接頭詞,名詞接続,*,*,*,*,*,み
2675 接頭詞,名詞接続,*,*,*,*,*,もと
2676 接頭詞,名詞接続,*,*,*,*,*,代
2677 接頭詞,名詞接続,*,*,*,*,*,低
2678 接頭詞,名詞接続,*,*,*,*,*,元
2679 接頭詞,名詞接続,*,*,*,*,*,全
2680 接頭詞,名詞接続,*,*,*,*,*,再
2681 接頭詞,名詞接続,*,*,*,*,*,初
2682 接頭詞,名詞接続,*,*,*,*,*,前
2683 接頭詞,名詞接続,*,*,*,*,*,各
2684 接頭詞,名詞接続,*,*,*,*,*,同
2685 接頭詞,名詞接続,*,*,*,*,*,大
2686 接頭詞,名詞接続,*,*,*,*,*,当
2687 接頭詞,名詞接続,*,*,*,*,*,御
2688 接頭詞,名詞接続,*,*,*,*,*,新
2689 接頭詞,名詞接続,*,*,*,*,*,最
2690 接頭詞,名詞接続,*,*,*,*,*,未
2691 接頭詞,名詞接続,*,*,*,*,*,本
2692 接頭詞,名詞接続,*,*,*,*,*,無
2693 接頭詞,名詞接続,*,*,*,*,*,第
2694 接頭詞,名詞接続,*,*,*,*,*,等
2695 接頭詞,名詞接続,*,*,*,*,*,約
2696 接頭詞,名詞接続,*,*,*,*,*,被
2697 接頭詞,名詞接続,*,*,*,*,*,超
2698 接頭詞,名詞接続,*,*,*,*,*,長
2699 接頭詞,名詞接続,*,*,*,*,*,非
2700 接頭詞,名詞接続,*,*,*,*,*,高
2701 接頭詞,形容詞接続,*,*,*,*,*,*
2702 接頭詞,数接続,*,*,*,*,*,*
2703 記号,アルファベット,*,*,*,*,*
2704 記号,一般,*,*,*,*,*
2705 記号,句点,*,*,*,*,*
2706 記号,括弧閉,*,*,*,*,*
2707 記号,括弧開,*,*,*,*,*
2708 記号,読点,*,*,*,*,*
2709 連体詞,*,*,*,*,*,*
2710 連体詞,*,*,*,*,*,あの
2711 連体詞,*,*,*,*,*,ある
2712 連体詞,*,*,*,*,*,この
2713 連体詞,*,*,*,*,*,こんな
2714 連体詞,*,*,*,*,*,その
2715 連体詞,*,*,*,*,*,そんな
2716 連体詞,*,*,*,*,*,とある
2717 連体詞,*,*,*,*,*,どの
2718 連体詞,*,*,*,*,*,どんな
2719 連体詞,*,*,*,*,*,わが
2720 連体詞,*,*,*,*,*,同じ
2721 連体詞,*,*,*,*,*,我が
